# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.action_flow import ActionFlow  # noqa: F401,E501
from pdf4me.model.job_flow_plan import JobFlowPlan  # noqa: F401,E501


class JobFlow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_flow_id': 'str',
        'tenant_id': 'str',
        'subscription_id': 'str',
        'application_id': 'str',
        'name': 'str',
        'action_flow': 'ActionFlow',
        'job_flow_plan': 'JobFlowPlan',
        'creation_date': 'datetime'
    }

    attribute_map = {
        'job_flow_id': 'jobFlowId',
        'tenant_id': 'tenantId',
        'subscription_id': 'subscriptionId',
        'application_id': 'applicationId',
        'name': 'name',
        'action_flow': 'actionFlow',
        'job_flow_plan': 'jobFlowPlan',
        'creation_date': 'creationDate'
    }

    def __init__(self, job_flow_id=None, tenant_id=None, subscription_id=None, application_id=None, name=None, action_flow=None, job_flow_plan=None, creation_date=None):  # noqa: E501
        """JobFlow - a model defined in Swagger"""  # noqa: E501

        self._job_flow_id = None
        self._tenant_id = None
        self._subscription_id = None
        self._application_id = None
        self._name = None
        self._action_flow = None
        self._job_flow_plan = None
        self._creation_date = None
        self.discriminator = None

        if job_flow_id is not None:
            self.job_flow_id = job_flow_id
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if application_id is not None:
            self.application_id = application_id
        if name is not None:
            self.name = name
        if action_flow is not None:
            self.action_flow = action_flow
        if job_flow_plan is not None:
            self.job_flow_plan = job_flow_plan
        if creation_date is not None:
            self.creation_date = creation_date

    @property
    def job_flow_id(self):
        """Gets the job_flow_id of this JobFlow.  # noqa: E501


        :return: The job_flow_id of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._job_flow_id

    @job_flow_id.setter
    def job_flow_id(self, job_flow_id):
        """Sets the job_flow_id of this JobFlow.


        :param job_flow_id: The job_flow_id of this JobFlow.  # noqa: E501
        :type: str
        """

        self._job_flow_id = job_flow_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this JobFlow.  # noqa: E501


        :return: The tenant_id of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this JobFlow.


        :param tenant_id: The tenant_id of this JobFlow.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def subscription_id(self):
        """Gets the subscription_id of this JobFlow.  # noqa: E501


        :return: The subscription_id of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this JobFlow.


        :param subscription_id: The subscription_id of this JobFlow.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def application_id(self):
        """Gets the application_id of this JobFlow.  # noqa: E501


        :return: The application_id of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this JobFlow.


        :param application_id: The application_id of this JobFlow.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    @property
    def name(self):
        """Gets the name of this JobFlow.  # noqa: E501


        :return: The name of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobFlow.


        :param name: The name of this JobFlow.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def action_flow(self):
        """Gets the action_flow of this JobFlow.  # noqa: E501


        :return: The action_flow of this JobFlow.  # noqa: E501
        :rtype: ActionFlow
        """
        return self._action_flow

    @action_flow.setter
    def action_flow(self, action_flow):
        """Sets the action_flow of this JobFlow.


        :param action_flow: The action_flow of this JobFlow.  # noqa: E501
        :type: ActionFlow
        """

        self._action_flow = action_flow

    @property
    def job_flow_plan(self):
        """Gets the job_flow_plan of this JobFlow.  # noqa: E501


        :return: The job_flow_plan of this JobFlow.  # noqa: E501
        :rtype: JobFlowPlan
        """
        return self._job_flow_plan

    @job_flow_plan.setter
    def job_flow_plan(self, job_flow_plan):
        """Sets the job_flow_plan of this JobFlow.


        :param job_flow_plan: The job_flow_plan of this JobFlow.  # noqa: E501
        :type: JobFlowPlan
        """

        self._job_flow_plan = job_flow_plan

    @property
    def creation_date(self):
        """Gets the creation_date of this JobFlow.  # noqa: E501


        :return: The creation_date of this JobFlow.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this JobFlow.


        :param creation_date: The creation_date of this JobFlow.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobFlow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobFlow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Pricing(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currency': 'str',
        'total_cost': 'float',
        'page_cnt': 'int',
        'document_cnt': 'int',
        'pricing_type_required': 'str',
        'pricing_type_of_user': 'str'
    }

    attribute_map = {
        'currency': 'currency',
        'total_cost': 'totalCost',
        'page_cnt': 'pageCnt',
        'document_cnt': 'documentCnt',
        'pricing_type_required': 'pricingTypeRequired',
        'pricing_type_of_user': 'pricingTypeOfUser'
    }

    def __init__(self, currency=None, total_cost=None, page_cnt=None, document_cnt=None, pricing_type_required=None, pricing_type_of_user=None):  # noqa: E501
        """Pricing - a model defined in Swagger"""  # noqa: E501

        self._currency = None
        self._total_cost = None
        self._page_cnt = None
        self._document_cnt = None
        self._pricing_type_required = None
        self._pricing_type_of_user = None
        self.discriminator = None

        if currency is not None:
            self.currency = currency
        if total_cost is not None:
            self.total_cost = total_cost
        if page_cnt is not None:
            self.page_cnt = page_cnt
        if document_cnt is not None:
            self.document_cnt = document_cnt
        if pricing_type_required is not None:
            self.pricing_type_required = pricing_type_required
        if pricing_type_of_user is not None:
            self.pricing_type_of_user = pricing_type_of_user

    @property
    def currency(self):
        """Gets the currency of this Pricing.  # noqa: E501


        :return: The currency of this Pricing.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Pricing.


        :param currency: The currency of this Pricing.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def total_cost(self):
        """Gets the total_cost of this Pricing.  # noqa: E501


        :return: The total_cost of this Pricing.  # noqa: E501
        :rtype: float
        """
        return self._total_cost

    @total_cost.setter
    def total_cost(self, total_cost):
        """Sets the total_cost of this Pricing.


        :param total_cost: The total_cost of this Pricing.  # noqa: E501
        :type: float
        """

        self._total_cost = total_cost

    @property
    def page_cnt(self):
        """Gets the page_cnt of this Pricing.  # noqa: E501


        :return: The page_cnt of this Pricing.  # noqa: E501
        :rtype: int
        """
        return self._page_cnt

    @page_cnt.setter
    def page_cnt(self, page_cnt):
        """Sets the page_cnt of this Pricing.


        :param page_cnt: The page_cnt of this Pricing.  # noqa: E501
        :type: int
        """

        self._page_cnt = page_cnt

    @property
    def document_cnt(self):
        """Gets the document_cnt of this Pricing.  # noqa: E501


        :return: The document_cnt of this Pricing.  # noqa: E501
        :rtype: int
        """
        return self._document_cnt

    @document_cnt.setter
    def document_cnt(self, document_cnt):
        """Sets the document_cnt of this Pricing.


        :param document_cnt: The document_cnt of this Pricing.  # noqa: E501
        :type: int
        """

        self._document_cnt = document_cnt

    @property
    def pricing_type_required(self):
        """Gets the pricing_type_required of this Pricing.  # noqa: E501


        :return: The pricing_type_required of this Pricing.  # noqa: E501
        :rtype: str
        """
        return self._pricing_type_required

    @pricing_type_required.setter
    def pricing_type_required(self, pricing_type_required):
        """Sets the pricing_type_required of this Pricing.


        :param pricing_type_required: The pricing_type_required of this Pricing.  # noqa: E501
        :type: str
        """
        allowed_values = ["free", "basic", "premium", "enterprise"]  # noqa: E501
        if pricing_type_required not in allowed_values:
            raise ValueError(
                "Invalid value for `pricing_type_required` ({0}), must be one of {1}"  # noqa: E501
                .format(pricing_type_required, allowed_values)
            )

        self._pricing_type_required = pricing_type_required

    @property
    def pricing_type_of_user(self):
        """Gets the pricing_type_of_user of this Pricing.  # noqa: E501


        :return: The pricing_type_of_user of this Pricing.  # noqa: E501
        :rtype: str
        """
        return self._pricing_type_of_user

    @pricing_type_of_user.setter
    def pricing_type_of_user(self, pricing_type_of_user):
        """Sets the pricing_type_of_user of this Pricing.


        :param pricing_type_of_user: The pricing_type_of_user of this Pricing.  # noqa: E501
        :type: str
        """
        allowed_values = ["free", "basic", "premium", "enterprise"]  # noqa: E501
        if pricing_type_of_user not in allowed_values:
            raise ValueError(
                "Invalid value for `pricing_type_of_user` ({0}), must be one of {1}"  # noqa: E501
                .format(pricing_type_of_user, allowed_values)
            )

        self._pricing_type_of_user = pricing_type_of_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Pricing, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pricing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import base64

from pdf4me.helper.json_converter import JsonConverter
from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.helper.response_checker import ResponseChecker
from pdf4me.model import Split


class SplitClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def split(self, split):
        """The predefined split is carried out.

        :param split: split configuration
        :type split: Split
        :return: ExtractRes, contains the document splinters of the original PDF document
        """

        # check split validity
        self.__check_split_object_validity(split)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=split,
                                                                   controller='Split/Split')

        return res

    def split_by_page_nr(self, page_nr, file):
        """Splits the PDF after the pageNr, this results in two smaller PDF documents.

        :param page_nr: determines after which page the split takes place
        :type page_nr: str:
        :param file: to split into two
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('pageNr', page_nr)]

        res = self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                          controller='Split/SplitByPageNr')

        # get json
        res = JsonConverter().load(res)

        # extract the two documents
        pdf_1 = base64.b64decode(res[0])
        pdf_2 = base64.b64decode(res[1])

        return pdf_1, pdf_2

    def split_recurring(self, page_nr, file):
        """Splits the PDF after the pageNr, this results in two smaller PDF documents.

        :param page_nr: determines after which page the split takes place
        :type page_nr: str:
        :param file: to split into two
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('pageNr', page_nr)]

        res = self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                          controller='Split/SplitRecurring')

        # get json
        res = JsonConverter().load(res)

        # extract the two documents
        pdfs = []
        for pdf in res:
            pdfs.append(base64.b64decode(pdf))
        # pdf_1 = base64.b64decode(res[0])
        # pdf_2 = base64.b64decode(res[1])

        return pdfs

    def __check_split_object_validity(self, split):
        """Checks whether the split object contains the essential information to be
        processed by the server."""

        if split is None:
            raise Pdf4meClientException('The split parameter cannot be None.')
        elif split.document is None or split.document.doc_data is None:
            raise Pdf4meClientException('The split document cannot be None.')
        elif split.split_action is None:
            raise Pdf4meClientException('The split_action cannot be None.')
        elif split.split_action.split_after_page is None or split.split_action.split_after_page == 0:
            raise Pdf4meClientException('The split_after_page of split_action cannot be None or zero.'
                                        'The first page of a PDF corresponds to page number one.')



import requests

from pdf4me.helper.json_converter import JsonConverter
from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException, Pdf4meBackendException
from pdf4me.helper.response_checker import ResponseChecker


# from pdf4me.helper.token_generator import TokenGenerator

class CustomHttp(object):

    def __init__(self, token, apiurl):

        self.token = token
        self.json_converter = JsonConverter()
        self.url = "https://api.pdf4me.com/"
        if apiurl is not None and len(apiurl) != 0:
            self.url = apiurl
        self.userAgent = "pdf4me-python/0.8.13"

    def post_universal_object(self, universal_object, controller):
        """Sends a post request to the specified controller with the given
        universal_object as a body.

        :param universal_object: object to be sent
        :type universal_object: object
        :param controller: swagger controller
        :type controller: str
        :return: post response
        """

        # prepare post request
        request_url = self.url + controller
        headers = {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Basic ' + self.token,
            'User-Agent': self.userAgent
        }

        # convert body to json
        body = self.json_converter.dump(element=universal_object)

        # send request
        res = requests.post(request_url, data=body, headers=headers)

        # check status code
        self.__check_status_code(res)

        # check docLogs for error messages
        self.__check_docLogs_for_error_messages(res)

        # read content from response
        json_response = self.json_converter.load(res.text)

        return json_response

    def post_wrapper(self, octet_streams, values, controller):
        """Builds a post requests from the given parameters.

        :param octet_streams: (key: file identifier, value: open(fileName, 'rb'))) pairs
        :type octet_streams: list
        :param values: (key: identifier of value, value: content of value) pairs
        :type values: list
        :param controller: swagger controller
        :type controller: str
        :return: post response
        """

        # prepare post request
        request_url = self.url + controller
        header = {'Authorization': 'Basic ' + self.token, 'User-Agent': self.userAgent}

        # build files
        if len(octet_streams) != 0:
            files = {key: value for (key, value) in octet_streams}
        else:
            files = None

        # build values
        if len(values) != 0:
            data = {key: value for (key, value) in values}
        else:
            data = None

        # send request
        if files is None:
            if data is None:
                raise Pdf4meClientException("Please provide at least one value or an octet-stream.")
            else:
                res = requests.post(request_url, data=data, headers=header)
        else:
            if data is None:
                res = requests.post(request_url, files=files, headers=header)
            else:
                res = requests.post(request_url, files=files, data=data, headers=header)

        # check status code
        self.__check_status_code(res)

        # check docLogs for error messages
        self.__check_docLogs_for_error_messages(res)

        return res.content

    def __check_status_code(self, response):
        '''
        Checks whether the status code is either 200 or 204, otw. throws a Pdf4meBackendException.
        :param response: post response
        :type response: requests.Response
        :return: None
        '''

        status_code = response.status_code
        status_reason = response.reason

        if status_code == 500:
            server_error = self.json_converter.load(response.text)['error_message']
            trace_id = self.json_converter.load(response.text)['trace_id']
            raise Pdf4meBackendException('HTTP 500 ' + status_reason + " : trace_id " + trace_id + " : " + server_error)
        elif status_code != 200 and status_code != 204:
            error = response.text
            raise Pdf4meBackendException('HTTP ' + str(status_code) + ': ' + status_reason + " : " + error)

    def __check_docLogs_for_error_messages(self, response):
        '''
        Checks whether the HTTP response's docLogs contain any error message, in case of an error
         a Pdf4meBackendException is thrown.
        :param response: post response
        :type response: requests.Response
        :return: None
        '''

        ResponseChecker().check_response_for_errors(response.text)



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Rectangle(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'x': 'int',
        'y': 'int',
        'width': 'int',
        'height': 'int'
    }

    attribute_map = {
        'x': 'x',
        'y': 'y',
        'width': 'width',
        'height': 'height'
    }

    def __init__(self, x=None, y=None, width=None, height=None):  # noqa: E501
        """Rectangle - a model defined in Swagger"""  # noqa: E501

        self._x = None
        self._y = None
        self._width = None
        self._height = None
        self.discriminator = None

        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height

    @property
    def x(self):
        """Gets the x of this Rectangle.  # noqa: E501


        :return: The x of this Rectangle.  # noqa: E501
        :rtype: int
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this Rectangle.


        :param x: The x of this Rectangle.  # noqa: E501
        :type: int
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this Rectangle.  # noqa: E501


        :return: The y of this Rectangle.  # noqa: E501
        :rtype: int
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this Rectangle.


        :param y: The y of this Rectangle.  # noqa: E501
        :type: int
        """

        self._y = y

    @property
    def width(self):
        """Gets the width of this Rectangle.  # noqa: E501


        :return: The width of this Rectangle.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this Rectangle.


        :param width: The width of this Rectangle.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this Rectangle.  # noqa: E501


        :return: The height of this Rectangle.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Rectangle.


        :param height: The height of this Rectangle.  # noqa: E501
        :type: int
        """

        self._height = height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Rectangle, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Rectangle):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.key_value_pair_string_object import KeyValuePairStringObject  # noqa: F401,E501


class Pdf4meAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'action_id': 'str',
        'action_type': 'str',
        'user_action': 'str',
        'action_config': 'str',
        'action_properties': 'list[KeyValuePairStringObject]'
    }

    attribute_map = {
        'action_id': 'actionId',
        'action_type': 'actionType',
        'user_action': 'userAction',
        'action_config': 'actionConfig',
        'action_properties': 'actionProperties'
    }

    def __init__(self, action_id=None, action_type=None, user_action=None, action_config=None, action_properties=None):  # noqa: E501
        """Pdf4meAction - a model defined in Swagger"""  # noqa: E501

        self._action_id = None
        self._action_type = None
        self._user_action = None
        self._action_config = None
        self._action_properties = None
        self.discriminator = None

        if action_id is not None:
            self.action_id = action_id
        if action_type is not None:
            self.action_type = action_type
        if user_action is not None:
            self.user_action = user_action
        if action_config is not None:
            self.action_config = action_config
        if action_properties is not None:
            self.action_properties = action_properties

    @property
    def action_id(self):
        """Gets the action_id of this Pdf4meAction.  # noqa: E501


        :return: The action_id of this Pdf4meAction.  # noqa: E501
        :rtype: str
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        """Sets the action_id of this Pdf4meAction.


        :param action_id: The action_id of this Pdf4meAction.  # noqa: E501
        :type: str
        """

        self._action_id = action_id

    @property
    def action_type(self):
        """Gets the action_type of this Pdf4meAction.  # noqa: E501


        :return: The action_type of this Pdf4meAction.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this Pdf4meAction.


        :param action_type: The action_type of this Pdf4meAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "user", "optimize", "pdfA", "ocrDocument", "ocrBusCard", "convertToPdf", "stamp", "split", "merge", "scanMrc", "createThumbnail", "createImage", "extract", "barCode"]  # noqa: E501
        if action_type not in allowed_values:
            raise ValueError(
                "Invalid value for `action_type` ({0}), must be one of {1}"  # noqa: E501
                .format(action_type, allowed_values)
            )

        self._action_type = action_type

    @property
    def user_action(self):
        """Gets the user_action of this Pdf4meAction.  # noqa: E501


        :return: The user_action of this Pdf4meAction.  # noqa: E501
        :rtype: str
        """
        return self._user_action

    @user_action.setter
    def user_action(self, user_action):
        """Sets the user_action of this Pdf4meAction.


        :param user_action: The user_action of this Pdf4meAction.  # noqa: E501
        :type: str
        """

        self._user_action = user_action

    @property
    def action_config(self):
        """Gets the action_config of this Pdf4meAction.  # noqa: E501


        :return: The action_config of this Pdf4meAction.  # noqa: E501
        :rtype: str
        """
        return self._action_config

    @action_config.setter
    def action_config(self, action_config):
        """Sets the action_config of this Pdf4meAction.


        :param action_config: The action_config of this Pdf4meAction.  # noqa: E501
        :type: str
        """

        self._action_config = action_config

    @property
    def action_properties(self):
        """Gets the action_properties of this Pdf4meAction.  # noqa: E501


        :return: The action_properties of this Pdf4meAction.  # noqa: E501
        :rtype: list[KeyValuePairStringObject]
        """
        return self._action_properties

    @action_properties.setter
    def action_properties(self, action_properties):
        """Sets the action_properties of this Pdf4meAction.


        :param action_properties: The action_properties of this Pdf4meAction.  # noqa: E501
        :type: list[KeyValuePairStringObject]
        """

        self._action_properties = action_properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Pdf4meAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pdf4meAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.doc_metadata import DocMetadata  # noqa: F401,E501
from pdf4me.model.document import Document  # noqa: F401,E501


class ConvertToPdfRes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document': 'Document',
        'in_doc_metadata': 'DocMetadata',
        'trace_id': 'str',
        'job_id': 'str'
    }

    attribute_map = {
        'document': 'document',
        'in_doc_metadata': 'inDocMetadata',
        'trace_id': 'traceId',
        'job_id': 'jobId'
    }

    def __init__(self, document=None, in_doc_metadata=None, trace_id=None, job_id=None):  # noqa: E501
        """ConvertToPdfRes - a model defined in Swagger"""  # noqa: E501

        self._document = None
        self._in_doc_metadata = None
        self._trace_id = None
        self._job_id = None
        self.discriminator = None

        if document is not None:
            self.document = document
        if in_doc_metadata is not None:
            self.in_doc_metadata = in_doc_metadata
        if trace_id is not None:
            self.trace_id = trace_id
        if job_id is not None:
            self.job_id = job_id

    @property
    def document(self):
        """Gets the document of this ConvertToPdfRes.  # noqa: E501

        Converted Document  # noqa: E501

        :return: The document of this ConvertToPdfRes.  # noqa: E501
        :rtype: Document
        """
        return self._document

    @document.setter
    def document(self, document):
        """Sets the document of this ConvertToPdfRes.

        Converted Document  # noqa: E501

        :param document: The document of this ConvertToPdfRes.  # noqa: E501
        :type: Document
        """

        self._document = document

    @property
    def in_doc_metadata(self):
        """Gets the in_doc_metadata of this ConvertToPdfRes.  # noqa: E501


        :return: The in_doc_metadata of this ConvertToPdfRes.  # noqa: E501
        :rtype: DocMetadata
        """
        return self._in_doc_metadata

    @in_doc_metadata.setter
    def in_doc_metadata(self, in_doc_metadata):
        """Sets the in_doc_metadata of this ConvertToPdfRes.


        :param in_doc_metadata: The in_doc_metadata of this ConvertToPdfRes.  # noqa: E501
        :type: DocMetadata
        """

        self._in_doc_metadata = in_doc_metadata

    @property
    def trace_id(self):
        """Gets the trace_id of this ConvertToPdfRes.  # noqa: E501


        :return: The trace_id of this ConvertToPdfRes.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this ConvertToPdfRes.


        :param trace_id: The trace_id of this ConvertToPdfRes.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    @property
    def job_id(self):
        """Gets the job_id of this ConvertToPdfRes.  # noqa: E501


        :return: The job_id of this ConvertToPdfRes.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this ConvertToPdfRes.


        :param job_id: The job_id of this ConvertToPdfRes.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConvertToPdfRes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConvertToPdfRes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.key_value_pair_string_string import KeyValuePairStringString  # noqa: F401,E501


class OptimizeAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'profile': 'str',
        'use_profile': 'bool',
        'remove_redundant_objects': 'bool',
        'subset_fonts': 'bool',
        'optimize_resources': 'bool',
        'force_compression_types': 'bool',
        'force_recompression': 'bool',
        'reduce_color_complexity': 'bool',
        'merge_embedded_fonts': 'bool',
        'bitonal_compressions': 'list[str]',
        'bitonal_resolution_dpi': 'float',
        'bitonal_threshold_dpi': 'float',
        'clip_images': 'bool',
        'continuous_compressions': 'list[str]',
        'linearize': 'bool',
        'image_quality': 'int',
        'indexed_compressions': 'list[str]',
        'dithering_mode': 'str',
        'color_resolution_dpi': 'float',
        'color_threshold_dpi': 'float',
        'monochrome_resolution_dpi': 'float',
        'monochrome_threshold_dpi': 'float',
        'resolution_dpi': 'int',
        'threshold_dpi': 'int',
        'strip': 'list[str]',
        'info_entries': 'list[KeyValuePairStringString]',
        'flatten_signature_fields': 'bool'
    }

    attribute_map = {
        'profile': 'profile',
        'use_profile': 'useProfile',
        'remove_redundant_objects': 'removeRedundantObjects',
        'subset_fonts': 'subsetFonts',
        'optimize_resources': 'optimizeResources',
        'force_compression_types': 'forceCompressionTypes',
        'force_recompression': 'forceRecompression',
        'reduce_color_complexity': 'reduceColorComplexity',
        'merge_embedded_fonts': 'mergeEmbeddedFonts',
        'bitonal_compressions': 'bitonalCompressions',
        'bitonal_resolution_dpi': 'bitonalResolutionDPI',
        'bitonal_threshold_dpi': 'bitonalThresholdDPI',
        'clip_images': 'clipImages',
        'continuous_compressions': 'continuousCompressions',
        'linearize': 'linearize',
        'image_quality': 'imageQuality',
        'indexed_compressions': 'indexedCompressions',
        'dithering_mode': 'ditheringMode',
        'color_resolution_dpi': 'colorResolutionDPI',
        'color_threshold_dpi': 'colorThresholdDPI',
        'monochrome_resolution_dpi': 'monochromeResolutionDPI',
        'monochrome_threshold_dpi': 'monochromeThresholdDPI',
        'resolution_dpi': 'resolutionDPI',
        'threshold_dpi': 'thresholdDPI',
        'strip': 'strip',
        'info_entries': 'infoEntries',
        'flatten_signature_fields': 'flattenSignatureFields'
    }

    def __init__(self, profile=None, use_profile=None, remove_redundant_objects=None, subset_fonts=None, optimize_resources=None, force_compression_types=None, force_recompression=None, reduce_color_complexity=None, merge_embedded_fonts=None, bitonal_compressions=None, bitonal_resolution_dpi=None, bitonal_threshold_dpi=None, clip_images=None, continuous_compressions=None, linearize=None, image_quality=None, indexed_compressions=None, dithering_mode=None, color_resolution_dpi=None, color_threshold_dpi=None, monochrome_resolution_dpi=None, monochrome_threshold_dpi=None, resolution_dpi=None, threshold_dpi=None, strip=None, info_entries=None, flatten_signature_fields=None):  # noqa: E501
        """OptimizeAction - a model defined in Swagger"""  # noqa: E501

        self._profile = None
        self._use_profile = None
        self._remove_redundant_objects = None
        self._subset_fonts = None
        self._optimize_resources = None
        self._force_compression_types = None
        self._force_recompression = None
        self._reduce_color_complexity = None
        self._merge_embedded_fonts = None
        self._bitonal_compressions = None
        self._bitonal_resolution_dpi = None
        self._bitonal_threshold_dpi = None
        self._clip_images = None
        self._continuous_compressions = None
        self._linearize = None
        self._image_quality = None
        self._indexed_compressions = None
        self._dithering_mode = None
        self._color_resolution_dpi = None
        self._color_threshold_dpi = None
        self._monochrome_resolution_dpi = None
        self._monochrome_threshold_dpi = None
        self._resolution_dpi = None
        self._threshold_dpi = None
        self._strip = None
        self._info_entries = None
        self._flatten_signature_fields = None
        self.discriminator = None

        if profile is not None:
            self.profile = profile
        self.use_profile = use_profile
        if remove_redundant_objects is not None:
            self.remove_redundant_objects = remove_redundant_objects
        if subset_fonts is not None:
            self.subset_fonts = subset_fonts
        if optimize_resources is not None:
            self.optimize_resources = optimize_resources
        if force_compression_types is not None:
            self.force_compression_types = force_compression_types
        if force_recompression is not None:
            self.force_recompression = force_recompression
        if reduce_color_complexity is not None:
            self.reduce_color_complexity = reduce_color_complexity
        if merge_embedded_fonts is not None:
            self.merge_embedded_fonts = merge_embedded_fonts
        if bitonal_compressions is not None:
            self.bitonal_compressions = bitonal_compressions
        if bitonal_resolution_dpi is not None:
            self.bitonal_resolution_dpi = bitonal_resolution_dpi
        if bitonal_threshold_dpi is not None:
            self.bitonal_threshold_dpi = bitonal_threshold_dpi
        if clip_images is not None:
            self.clip_images = clip_images
        if continuous_compressions is not None:
            self.continuous_compressions = continuous_compressions
        if linearize is not None:
            self.linearize = linearize
        if image_quality is not None:
            self.image_quality = image_quality
        if indexed_compressions is not None:
            self.indexed_compressions = indexed_compressions
        if dithering_mode is not None:
            self.dithering_mode = dithering_mode
        if color_resolution_dpi is not None:
            self.color_resolution_dpi = color_resolution_dpi
        if color_threshold_dpi is not None:
            self.color_threshold_dpi = color_threshold_dpi
        if monochrome_resolution_dpi is not None:
            self.monochrome_resolution_dpi = monochrome_resolution_dpi
        if monochrome_threshold_dpi is not None:
            self.monochrome_threshold_dpi = monochrome_threshold_dpi
        if resolution_dpi is not None:
            self.resolution_dpi = resolution_dpi
        if threshold_dpi is not None:
            self.threshold_dpi = threshold_dpi
        if strip is not None:
            self.strip = strip
        if info_entries is not None:
            self.info_entries = info_entries
        if flatten_signature_fields is not None:
            self.flatten_signature_fields = flatten_signature_fields

    @property
    def profile(self):
        """Gets the profile of this OptimizeAction.  # noqa: E501

        With this property one of the predefined optimization profiles can be set. If a profile is set then all the properties  listed in TPDFOptimizationProfile(table Profile Settings) are set to their respective values.Properties not  listed in this table are left unchanged.  One way of quickly arriving at a specific setting is to first set the Profile and then adapt the configuration by  setting some of the individual properties.  # noqa: E501

        :return: The profile of this OptimizeAction.  # noqa: E501
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this OptimizeAction.

        With this property one of the predefined optimization profiles can be set. If a profile is set then all the properties  listed in TPDFOptimizationProfile(table Profile Settings) are set to their respective values.Properties not  listed in this table are left unchanged.  One way of quickly arriving at a specific setting is to first set the Profile and then adapt the configuration by  setting some of the individual properties.  # noqa: E501

        :param profile: The profile of this OptimizeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["default", "web", "print", "max"]  # noqa: E501
        if profile not in allowed_values:
            raise ValueError(
                "Invalid value for `profile` ({0}), must be one of {1}"  # noqa: E501
                .format(profile, allowed_values)
            )

        self._profile = profile

    @property
    def use_profile(self):
        """Gets the use_profile of this OptimizeAction.  # noqa: E501


        :return: The use_profile of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._use_profile

    @use_profile.setter
    def use_profile(self, use_profile):
        """Sets the use_profile of this OptimizeAction.


        :param use_profile: The use_profile of this OptimizeAction.  # noqa: E501
        :type: bool
        """
        if use_profile is None:
            raise ValueError("Invalid value for `use_profile`, must not be `None`")  # noqa: E501

        self._use_profile = use_profile

    @property
    def remove_redundant_objects(self):
        """Gets the remove_redundant_objects of this OptimizeAction.  # noqa: E501

        Get or set whether redundant objects should be removed. If this property is  set to True, duplicate objects are removed in order to reduce the file size.    {default: false}  # noqa: E501

        :return: The remove_redundant_objects of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._remove_redundant_objects

    @remove_redundant_objects.setter
    def remove_redundant_objects(self, remove_redundant_objects):
        """Sets the remove_redundant_objects of this OptimizeAction.

        Get or set whether redundant objects should be removed. If this property is  set to True, duplicate objects are removed in order to reduce the file size.    {default: false}  # noqa: E501

        :param remove_redundant_objects: The remove_redundant_objects of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._remove_redundant_objects = remove_redundant_objects

    @property
    def subset_fonts(self):
        """Gets the subset_fonts of this OptimizeAction.  # noqa: E501

        This property influences two optimizations related to subsetted fonts:  - Subset embedded fonts.  - Merge embedded font programs of different subsets of the same font, granted they can be merged.   <para>  Sub-setting refers to removing those glyphs in a font that are not actually  used in any text contained in the PDF.   </para>{default: false}  # noqa: E501

        :return: The subset_fonts of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._subset_fonts

    @subset_fonts.setter
    def subset_fonts(self, subset_fonts):
        """Sets the subset_fonts of this OptimizeAction.

        This property influences two optimizations related to subsetted fonts:  - Subset embedded fonts.  - Merge embedded font programs of different subsets of the same font, granted they can be merged.   <para>  Sub-setting refers to removing those glyphs in a font that are not actually  used in any text contained in the PDF.   </para>{default: false}  # noqa: E501

        :param subset_fonts: The subset_fonts of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._subset_fonts = subset_fonts

    @property
    def optimize_resources(self):
        """Gets the optimize_resources of this OptimizeAction.  # noqa: E501

        Get or set whether resources should be optimized. If set, unused resources  such as images, fonts, and color spaces are removed.Also content streams  are re-built.    {default: false}  # noqa: E501

        :return: The optimize_resources of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._optimize_resources

    @optimize_resources.setter
    def optimize_resources(self, optimize_resources):
        """Sets the optimize_resources of this OptimizeAction.

        Get or set whether resources should be optimized. If set, unused resources  such as images, fonts, and color spaces are removed.Also content streams  are re-built.    {default: false}  # noqa: E501

        :param optimize_resources: The optimize_resources of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._optimize_resources = optimize_resources

    @property
    def force_compression_types(self):
        """Gets the force_compression_types of this OptimizeAction.  # noqa: E501

        If this option is set, then re-compression of images is forced if an image in the  input PDF has a compression type that differs from the compression types  given in ContinuousCompressions, BitonalCompressions, or IndexedCompressions. Use this option if you want to allow only the given  compression types for images in the output PDF.  {default: false}  # noqa: E501

        :return: The force_compression_types of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._force_compression_types

    @force_compression_types.setter
    def force_compression_types(self, force_compression_types):
        """Sets the force_compression_types of this OptimizeAction.

        If this option is set, then re-compression of images is forced if an image in the  input PDF has a compression type that differs from the compression types  given in ContinuousCompressions, BitonalCompressions, or IndexedCompressions. Use this option if you want to allow only the given  compression types for images in the output PDF.  {default: false}  # noqa: E501

        :param force_compression_types: The force_compression_types of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._force_compression_types = force_compression_types

    @property
    def force_recompression(self):
        """Gets the force_recompression of this OptimizeAction.  # noqa: E501

        If set, all images are always recompressed.If not set (default), images are only  recompressed if the resulting image is smaller than the original, i.e.requires  less bytes to store in the file.    {default: false}  # noqa: E501

        :return: The force_recompression of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._force_recompression

    @force_recompression.setter
    def force_recompression(self, force_recompression):
        """Sets the force_recompression of this OptimizeAction.

        If set, all images are always recompressed.If not set (default), images are only  recompressed if the resulting image is smaller than the original, i.e.requires  less bytes to store in the file.    {default: false}  # noqa: E501

        :param force_recompression: The force_recompression of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._force_recompression = force_recompression

    @property
    def reduce_color_complexity(self):
        """Gets the reduce_color_complexity of this OptimizeAction.  # noqa: E501

        This property is used to enable color complexity reduction of images. (See  also Provided Features for Optimizing Images.)  If enabled then images with device color spaces(DeviceRGB, DeviceCMYK,  or DeviceGray) and indexed images with a device color space as base color  space are analyzed and if possible converted as follows:  - An image with DeviceRGB or DeviceCMYK color space in which all pixels  are gray is converted to a grayscale image with DeviceGray color space.  - An image that contains only black and white pixels is converted into a bitonal image.  - An image in which all the pixels have the same color is down-sampled to one pixel.  Furthermore, images’ masks and soft masks are optimized as follows:  - A soft mask that contains only black and white pixels is converted to a mask.  - A (soft) mask that is opaque is removed.    {default: false}  # noqa: E501

        :return: The reduce_color_complexity of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._reduce_color_complexity

    @reduce_color_complexity.setter
    def reduce_color_complexity(self, reduce_color_complexity):
        """Sets the reduce_color_complexity of this OptimizeAction.

        This property is used to enable color complexity reduction of images. (See  also Provided Features for Optimizing Images.)  If enabled then images with device color spaces(DeviceRGB, DeviceCMYK,  or DeviceGray) and indexed images with a device color space as base color  space are analyzed and if possible converted as follows:  - An image with DeviceRGB or DeviceCMYK color space in which all pixels  are gray is converted to a grayscale image with DeviceGray color space.  - An image that contains only black and white pixels is converted into a bitonal image.  - An image in which all the pixels have the same color is down-sampled to one pixel.  Furthermore, images’ masks and soft masks are optimized as follows:  - A soft mask that contains only black and white pixels is converted to a mask.  - A (soft) mask that is opaque is removed.    {default: false}  # noqa: E501

        :param reduce_color_complexity: The reduce_color_complexity of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._reduce_color_complexity = reduce_color_complexity

    @property
    def merge_embedded_fonts(self):
        """Gets the merge_embedded_fonts of this OptimizeAction.  # noqa: E501

        Merge embedded font programs. Font programs can be merged, if they  originate from the same font, e.g.they are of the same type, have the same  name and encoding.Merging of Type1(PostScript) and TrueType fonts is supported.  # noqa: E501

        :return: The merge_embedded_fonts of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._merge_embedded_fonts

    @merge_embedded_fonts.setter
    def merge_embedded_fonts(self, merge_embedded_fonts):
        """Sets the merge_embedded_fonts of this OptimizeAction.

        Merge embedded font programs. Font programs can be merged, if they  originate from the same font, e.g.they are of the same type, have the same  name and encoding.Merging of Type1(PostScript) and TrueType fonts is supported.  # noqa: E501

        :param merge_embedded_fonts: The merge_embedded_fonts of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._merge_embedded_fonts = merge_embedded_fonts

    @property
    def bitonal_compressions(self):
        """Gets the bitonal_compressions of this OptimizeAction.  # noqa: E501

        Get or set the compression types for bi-tonal images.  Several values can be combined.The following values are allowed:  ComprAttemptNone  ComprAttemptRaw  ComprAttemptFlate  ComprAttemptLZW  ComprAttemptGroup3  ComprAttemptGroup4  ComprAttemptSource  ComprAttemptJBIG2  Other values are ignored.   <para>  During optimization, all set compression types are tried and the one resulting in the least memory footprint is taken.  Typically, CCITT Group 4 or JBIG2 is used for bi-tonal compression. Due to the simpler algorithm CCITT Group 4 has  the advantage of being faster. JBIG2 can achieve compression ratios that are up to twice as high as CCITT Group 4  at the cost of longer computation time.   </para>{default: ComprAttemptNone}  # noqa: E501

        :return: The bitonal_compressions of this OptimizeAction.  # noqa: E501
        :rtype: list[str]
        """
        return self._bitonal_compressions

    @bitonal_compressions.setter
    def bitonal_compressions(self, bitonal_compressions):
        """Sets the bitonal_compressions of this OptimizeAction.

        Get or set the compression types for bi-tonal images.  Several values can be combined.The following values are allowed:  ComprAttemptNone  ComprAttemptRaw  ComprAttemptFlate  ComprAttemptLZW  ComprAttemptGroup3  ComprAttemptGroup4  ComprAttemptSource  ComprAttemptJBIG2  Other values are ignored.   <para>  During optimization, all set compression types are tried and the one resulting in the least memory footprint is taken.  Typically, CCITT Group 4 or JBIG2 is used for bi-tonal compression. Due to the simpler algorithm CCITT Group 4 has  the advantage of being faster. JBIG2 can achieve compression ratios that are up to twice as high as CCITT Group 4  at the cost of longer computation time.   </para>{default: ComprAttemptNone}  # noqa: E501

        :param bitonal_compressions: The bitonal_compressions of this OptimizeAction.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["none", "raw", "jPEG", "flate", "lZW", "group3", "group3_2D", "group4", "jBIG2", "jPEG2000", "mRC", "source"]  # noqa: E501
        if not set(bitonal_compressions).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `bitonal_compressions` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(bitonal_compressions) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._bitonal_compressions = bitonal_compressions

    @property
    def bitonal_resolution_dpi(self):
        """Gets the bitonal_resolution_dpi of this OptimizeAction.  # noqa: E501

        Get or set the target resolution in dots per inch (DPI) after re-sampling images  for bi-tonal images.See also ResolutionDPI.    {default: 200}  # noqa: E501

        :return: The bitonal_resolution_dpi of this OptimizeAction.  # noqa: E501
        :rtype: float
        """
        return self._bitonal_resolution_dpi

    @bitonal_resolution_dpi.setter
    def bitonal_resolution_dpi(self, bitonal_resolution_dpi):
        """Sets the bitonal_resolution_dpi of this OptimizeAction.

        Get or set the target resolution in dots per inch (DPI) after re-sampling images  for bi-tonal images.See also ResolutionDPI.    {default: 200}  # noqa: E501

        :param bitonal_resolution_dpi: The bitonal_resolution_dpi of this OptimizeAction.  # noqa: E501
        :type: float
        """

        self._bitonal_resolution_dpi = bitonal_resolution_dpi

    @property
    def bitonal_threshold_dpi(self):
        """Gets the bitonal_threshold_dpi of this OptimizeAction.  # noqa: E501

        Get or set the threshold resolution in dots per inch (DPI) to selectively activate  re-sampling for bi-tonal images.The value -1 deactivates re-sampling for bitonal images. See also ThresholdDPI.    {default: -1}  # noqa: E501

        :return: The bitonal_threshold_dpi of this OptimizeAction.  # noqa: E501
        :rtype: float
        """
        return self._bitonal_threshold_dpi

    @bitonal_threshold_dpi.setter
    def bitonal_threshold_dpi(self, bitonal_threshold_dpi):
        """Sets the bitonal_threshold_dpi of this OptimizeAction.

        Get or set the threshold resolution in dots per inch (DPI) to selectively activate  re-sampling for bi-tonal images.The value -1 deactivates re-sampling for bitonal images. See also ThresholdDPI.    {default: -1}  # noqa: E501

        :param bitonal_threshold_dpi: The bitonal_threshold_dpi of this OptimizeAction.  # noqa: E501
        :type: float
        """

        self._bitonal_threshold_dpi = bitonal_threshold_dpi

    @property
    def clip_images(self):
        """Gets the clip_images of this OptimizeAction.  # noqa: E501

        Get or set the option to clip images. When enabled, then invisible parts of images are clipped (cropped).   While this does not affect visual parts of images, it may have a minor visual impact because clipped   images are re-compressed. Pre-blended images are not clipped. Enabling this property will also   enable the OptimizeResources property.                {default: false}  # noqa: E501

        :return: The clip_images of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._clip_images

    @clip_images.setter
    def clip_images(self, clip_images):
        """Sets the clip_images of this OptimizeAction.

        Get or set the option to clip images. When enabled, then invisible parts of images are clipped (cropped).   While this does not affect visual parts of images, it may have a minor visual impact because clipped   images are re-compressed. Pre-blended images are not clipped. Enabling this property will also   enable the OptimizeResources property.                {default: false}  # noqa: E501

        :param clip_images: The clip_images of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._clip_images = clip_images

    @property
    def continuous_compressions(self):
        """Gets the continuous_compressions of this OptimizeAction.  # noqa: E501

        Get or set the compression types to be tried for continuous images, i.e. RGB, CMYK, and grayscale images.  See also TPDFComprAttempt. Several values can be combined with bitwise or operators.  Other values are ignored. During optimization, all set compression types are tried and the one resulting in   the least memory footprint is taken.    {default: ComprAttemptNone}  # noqa: E501

        :return: The continuous_compressions of this OptimizeAction.  # noqa: E501
        :rtype: list[str]
        """
        return self._continuous_compressions

    @continuous_compressions.setter
    def continuous_compressions(self, continuous_compressions):
        """Sets the continuous_compressions of this OptimizeAction.

        Get or set the compression types to be tried for continuous images, i.e. RGB, CMYK, and grayscale images.  See also TPDFComprAttempt. Several values can be combined with bitwise or operators.  Other values are ignored. During optimization, all set compression types are tried and the one resulting in   the least memory footprint is taken.    {default: ComprAttemptNone}  # noqa: E501

        :param continuous_compressions: The continuous_compressions of this OptimizeAction.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["none", "raw", "jPEG", "flate", "lZW", "group3", "group3_2D", "group4", "jBIG2", "jPEG2000", "mRC", "source"]  # noqa: E501
        if not set(continuous_compressions).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `continuous_compressions` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(continuous_compressions) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._continuous_compressions = continuous_compressions

    @property
    def linearize(self):
        """Gets the linearize of this OptimizeAction.  # noqa: E501

        Get or set whether to linearize the PDF output file, i.e. optimize file for fast web access.   A linearized document has a slightly larger file size than a non-linearized file and provides the following main features:   - When a document is opened in a PDF viewer of a web browser, the first page can be viewed without downloading the entire   PDF file.In contrast, a non-linearized PDF file must be downloaded completely before the first page can be displayed.  - When another page is requested by the user, that page is displayed as quickly as possible and incrementally as   data arrives, without downloading the entire PDF file.   <para>  Signed files cannot be linearizes. So this property must be set to False if a digital signature is applied.   </para>{default: false}  # noqa: E501

        :return: The linearize of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._linearize

    @linearize.setter
    def linearize(self, linearize):
        """Sets the linearize of this OptimizeAction.

        Get or set whether to linearize the PDF output file, i.e. optimize file for fast web access.   A linearized document has a slightly larger file size than a non-linearized file and provides the following main features:   - When a document is opened in a PDF viewer of a web browser, the first page can be viewed without downloading the entire   PDF file.In contrast, a non-linearized PDF file must be downloaded completely before the first page can be displayed.  - When another page is requested by the user, that page is displayed as quickly as possible and incrementally as   data arrives, without downloading the entire PDF file.   <para>  Signed files cannot be linearizes. So this property must be set to False if a digital signature is applied.   </para>{default: false}  # noqa: E501

        :param linearize: The linearize of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._linearize = linearize

    @property
    def image_quality(self):
        """Gets the image_quality of this OptimizeAction.  # noqa: E501

        Get or set the quality index of lossy compression types. This value ranges   from 1 to 100 and is applied to JPEG and JPEG2000 compression.For  JPEG2000, a quality index of 100 means lossless compression.JPEG compression is always lossy.    {default: 75}  # noqa: E501

        :return: The image_quality of this OptimizeAction.  # noqa: E501
        :rtype: int
        """
        return self._image_quality

    @image_quality.setter
    def image_quality(self, image_quality):
        """Sets the image_quality of this OptimizeAction.

        Get or set the quality index of lossy compression types. This value ranges   from 1 to 100 and is applied to JPEG and JPEG2000 compression.For  JPEG2000, a quality index of 100 means lossless compression.JPEG compression is always lossy.    {default: 75}  # noqa: E501

        :param image_quality: The image_quality of this OptimizeAction.  # noqa: E501
        :type: int
        """

        self._image_quality = image_quality

    @property
    def indexed_compressions(self):
        """Gets the indexed_compressions of this OptimizeAction.  # noqa: E501

        Get or set the compression types for images that have an indexed (“palette”)  color space.See also TPDFComprAttempt.  Several values can be combined with bitwise or operators.The following values are allowed:  - ComprAttemptNone  - ComprAttemptRaw  - ComprAttemptFlate  - ComprAttemptLZW  - ComprAttemptSource  Other values are ignored.   <para>  During optimization, all set compression types are tried and the one resulting in the least memory footprint is taken.   </para>{default: ComprAttemptFlate}  # noqa: E501

        :return: The indexed_compressions of this OptimizeAction.  # noqa: E501
        :rtype: list[str]
        """
        return self._indexed_compressions

    @indexed_compressions.setter
    def indexed_compressions(self, indexed_compressions):
        """Sets the indexed_compressions of this OptimizeAction.

        Get or set the compression types for images that have an indexed (“palette”)  color space.See also TPDFComprAttempt.  Several values can be combined with bitwise or operators.The following values are allowed:  - ComprAttemptNone  - ComprAttemptRaw  - ComprAttemptFlate  - ComprAttemptLZW  - ComprAttemptSource  Other values are ignored.   <para>  During optimization, all set compression types are tried and the one resulting in the least memory footprint is taken.   </para>{default: ComprAttemptFlate}  # noqa: E501

        :param indexed_compressions: The indexed_compressions of this OptimizeAction.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["none", "raw", "jPEG", "flate", "lZW", "group3", "group3_2D", "group4", "jBIG2", "jPEG2000", "mRC", "source"]  # noqa: E501
        if not set(indexed_compressions).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `indexed_compressions` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(indexed_compressions) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._indexed_compressions = indexed_compressions

    @property
    def dithering_mode(self):
        """Gets the dithering_mode of this OptimizeAction.  # noqa: E501

        This option enables or disables dithering when down-sampling bi-tonal images.  The only values supported are eDitherNone and eDitherFloydSteinberg.  Some bi-tonal images try to evoke the impression of different levels of gray   by randomly setting pixels to black.If dithering is applied during downsampling    then the gray levels of such images are preserved better.If dithering is switched    off then lines (e.g.text glyphs) are preserved better.      {default: DitherNone}  # noqa: E501

        :return: The dithering_mode of this OptimizeAction.  # noqa: E501
        :rtype: str
        """
        return self._dithering_mode

    @dithering_mode.setter
    def dithering_mode(self, dithering_mode):
        """Sets the dithering_mode of this OptimizeAction.

        This option enables or disables dithering when down-sampling bi-tonal images.  The only values supported are eDitherNone and eDitherFloydSteinberg.  Some bi-tonal images try to evoke the impression of different levels of gray   by randomly setting pixels to black.If dithering is applied during downsampling    then the gray levels of such images are preserved better.If dithering is switched    off then lines (e.g.text glyphs) are preserved better.      {default: DitherNone}  # noqa: E501

        :param dithering_mode: The dithering_mode of this OptimizeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "floydSteinberg", "halftone", "pattern", "g3Optimized", "g4Optimized", "atkinson"]  # noqa: E501
        if dithering_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `dithering_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(dithering_mode, allowed_values)
            )

        self._dithering_mode = dithering_mode

    @property
    def color_resolution_dpi(self):
        """Gets the color_resolution_dpi of this OptimizeAction.  # noqa: E501

        Get or set the target resolution in dots per inch (DPI) after re-sampling images  for color images.See also ResolutionDPI.    {default: 150}  # noqa: E501

        :return: The color_resolution_dpi of this OptimizeAction.  # noqa: E501
        :rtype: float
        """
        return self._color_resolution_dpi

    @color_resolution_dpi.setter
    def color_resolution_dpi(self, color_resolution_dpi):
        """Sets the color_resolution_dpi of this OptimizeAction.

        Get or set the target resolution in dots per inch (DPI) after re-sampling images  for color images.See also ResolutionDPI.    {default: 150}  # noqa: E501

        :param color_resolution_dpi: The color_resolution_dpi of this OptimizeAction.  # noqa: E501
        :type: float
        """

        self._color_resolution_dpi = color_resolution_dpi

    @property
    def color_threshold_dpi(self):
        """Gets the color_threshold_dpi of this OptimizeAction.  # noqa: E501

        Get or set the threshold resolution in dots per inch (DPI) to selectively activate  re-sampling for color images.The value -1 deactivates re-sampling for color  images. See also ThresholdDPI.    {default: -1}  # noqa: E501

        :return: The color_threshold_dpi of this OptimizeAction.  # noqa: E501
        :rtype: float
        """
        return self._color_threshold_dpi

    @color_threshold_dpi.setter
    def color_threshold_dpi(self, color_threshold_dpi):
        """Sets the color_threshold_dpi of this OptimizeAction.

        Get or set the threshold resolution in dots per inch (DPI) to selectively activate  re-sampling for color images.The value -1 deactivates re-sampling for color  images. See also ThresholdDPI.    {default: -1}  # noqa: E501

        :param color_threshold_dpi: The color_threshold_dpi of this OptimizeAction.  # noqa: E501
        :type: float
        """

        self._color_threshold_dpi = color_threshold_dpi

    @property
    def monochrome_resolution_dpi(self):
        """Gets the monochrome_resolution_dpi of this OptimizeAction.  # noqa: E501

        Get or set target resolution in dots per inch (DPI) after re-sampling images  for monochrome images.See also ResolutionDPI.    {default: 150}  # noqa: E501

        :return: The monochrome_resolution_dpi of this OptimizeAction.  # noqa: E501
        :rtype: float
        """
        return self._monochrome_resolution_dpi

    @monochrome_resolution_dpi.setter
    def monochrome_resolution_dpi(self, monochrome_resolution_dpi):
        """Sets the monochrome_resolution_dpi of this OptimizeAction.

        Get or set target resolution in dots per inch (DPI) after re-sampling images  for monochrome images.See also ResolutionDPI.    {default: 150}  # noqa: E501

        :param monochrome_resolution_dpi: The monochrome_resolution_dpi of this OptimizeAction.  # noqa: E501
        :type: float
        """

        self._monochrome_resolution_dpi = monochrome_resolution_dpi

    @property
    def monochrome_threshold_dpi(self):
        """Gets the monochrome_threshold_dpi of this OptimizeAction.  # noqa: E501

        Get or set the threshold resolution in dots per inch (DPI) to selectively activate  re-sampling for monochrome images.The value -1 deactivates re-sampling  for monochrome images. See also ThresholdDPI.    {default: -1}  # noqa: E501

        :return: The monochrome_threshold_dpi of this OptimizeAction.  # noqa: E501
        :rtype: float
        """
        return self._monochrome_threshold_dpi

    @monochrome_threshold_dpi.setter
    def monochrome_threshold_dpi(self, monochrome_threshold_dpi):
        """Sets the monochrome_threshold_dpi of this OptimizeAction.

        Get or set the threshold resolution in dots per inch (DPI) to selectively activate  re-sampling for monochrome images.The value -1 deactivates re-sampling  for monochrome images. See also ThresholdDPI.    {default: -1}  # noqa: E501

        :param monochrome_threshold_dpi: The monochrome_threshold_dpi of this OptimizeAction.  # noqa: E501
        :type: float
        """

        self._monochrome_threshold_dpi = monochrome_threshold_dpi

    @property
    def resolution_dpi(self):
        """Gets the resolution_dpi of this OptimizeAction.  # noqa: E501

        Get or set the resolution in DPI (dots per inch) after re-sampling images.  This property affects all three image compression types(BitonalResolutionDPI, ColorResolutionDPI, MonochromeResolutionDPI).  A typical value for the resolution when optimizing for the web is 150 DPI.For  printing typically no re-sampling is applied(see property ThresholdDPI).  Pre-blended images, images with a color key mask, mask, and soft mask images are not re-sampled.  When getting ResolutionDPI, the property returns the target resolution in DPI for color images.    {default: Different defaults apply to different image types}  # noqa: E501

        :return: The resolution_dpi of this OptimizeAction.  # noqa: E501
        :rtype: int
        """
        return self._resolution_dpi

    @resolution_dpi.setter
    def resolution_dpi(self, resolution_dpi):
        """Sets the resolution_dpi of this OptimizeAction.

        Get or set the resolution in DPI (dots per inch) after re-sampling images.  This property affects all three image compression types(BitonalResolutionDPI, ColorResolutionDPI, MonochromeResolutionDPI).  A typical value for the resolution when optimizing for the web is 150 DPI.For  printing typically no re-sampling is applied(see property ThresholdDPI).  Pre-blended images, images with a color key mask, mask, and soft mask images are not re-sampled.  When getting ResolutionDPI, the property returns the target resolution in DPI for color images.    {default: Different defaults apply to different image types}  # noqa: E501

        :param resolution_dpi: The resolution_dpi of this OptimizeAction.  # noqa: E501
        :type: int
        """

        self._resolution_dpi = resolution_dpi

    @property
    def threshold_dpi(self):
        """Gets the threshold_dpi of this OptimizeAction.  # noqa: E501

        Set the threshold in DPI (dots per inch) to selectively activate re-sampling.  Only images with a resolution above the threshold DPI will be re-sampled.  This property affects all three image compression types(BitonalThresholdDPI, ColorThresholdDPI, MonochromeThresholdDPI). The  value -1 deactivates re-sampling.    {default: -1}  # noqa: E501

        :return: The threshold_dpi of this OptimizeAction.  # noqa: E501
        :rtype: int
        """
        return self._threshold_dpi

    @threshold_dpi.setter
    def threshold_dpi(self, threshold_dpi):
        """Sets the threshold_dpi of this OptimizeAction.

        Set the threshold in DPI (dots per inch) to selectively activate re-sampling.  Only images with a resolution above the threshold DPI will be re-sampled.  This property affects all three image compression types(BitonalThresholdDPI, ColorThresholdDPI, MonochromeThresholdDPI). The  value -1 deactivates re-sampling.    {default: -1}  # noqa: E501

        :param threshold_dpi: The threshold_dpi of this OptimizeAction.  # noqa: E501
        :type: int
        """

        self._threshold_dpi = threshold_dpi

    @property
    def strip(self):
        """Gets the strip of this OptimizeAction.  # noqa: E501

         Get or set the stripping mode. This mode can be configured to remove unneeded data of a PDF document such as Threads, Metadata, the PieceInfo,  the StructTreeRoot entry, embedded Thumbs and the SpiderInfo entry.Also  this mode is used to indicate whether to flatten form fields, links, and other  annotations.Multiple values of TPDFStripType can be combined with the  bitwise or operator.     {default: StripThreads}  # noqa: E501

        :return: The strip of this OptimizeAction.  # noqa: E501
        :rtype: list[str]
        """
        return self._strip

    @strip.setter
    def strip(self, strip):
        """Sets the strip of this OptimizeAction.

         Get or set the stripping mode. This mode can be configured to remove unneeded data of a PDF document such as Threads, Metadata, the PieceInfo,  the StructTreeRoot entry, embedded Thumbs and the SpiderInfo entry.Also  this mode is used to indicate whether to flatten form fields, links, and other  annotations.Multiple values of TPDFStripType can be combined with the  bitwise or operator.     {default: StripThreads}  # noqa: E501

        :param strip: The strip of this OptimizeAction.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["threads", "metadata", "pieceInfo", "structTree", "thumb", "spider", "alternates", "forms", "links", "annots", "formsAnnots", "outputIntents", "all"]  # noqa: E501
        if not set(strip).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `strip` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(strip) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._strip = strip

    @property
    def info_entries(self):
        """Gets the info_entries of this OptimizeAction.  # noqa: E501

         Set a key-value pair in the document info dictionary. Values of predefined keys are also stored in the XMP metadata.  Popular entries specified in the PDF Reference 1.7 and accepted by most PDF viewers are \"Title\", \"Author\",  \"Subject\", \"Creator\" (sometimes referred to as Application), and \"Producer\" (sometimes referred to as   PDF Creator).  # noqa: E501

        :return: The info_entries of this OptimizeAction.  # noqa: E501
        :rtype: list[KeyValuePairStringString]
        """
        return self._info_entries

    @info_entries.setter
    def info_entries(self, info_entries):
        """Sets the info_entries of this OptimizeAction.

         Set a key-value pair in the document info dictionary. Values of predefined keys are also stored in the XMP metadata.  Popular entries specified in the PDF Reference 1.7 and accepted by most PDF viewers are \"Title\", \"Author\",  \"Subject\", \"Creator\" (sometimes referred to as Application), and \"Producer\" (sometimes referred to as   PDF Creator).  # noqa: E501

        :param info_entries: The info_entries of this OptimizeAction.  # noqa: E501
        :type: list[KeyValuePairStringString]
        """

        self._info_entries = info_entries

    @property
    def flatten_signature_fields(self):
        """Gets the flatten_signature_fields of this OptimizeAction.  # noqa: E501

        A signature in a PDF consist of two parts:  a.The invisible digital signature in the PDF.  b.The visual appearance that was attributed to the signature.  Part (a) can be used by a viewing application, to verify that a document has not changed since it has been signed  and report this to the user.Part(b) is merely a “decorative” element on the page without further significance.  When optimizing a PDF, the PDF is altered and hence the digital signature is broken.Therefore, all signatures are removed  , including parts(a) and(b).  When the property FlattenSignatureFields is set to True, then digital signatures(parts (a)) are still removed,  but their visual appearances(parts (b)) are flattened.I.e.the latter are retained and drawn as non-editable graphic  onto the page.  <para>  Note: The resulting PDF can be misleading as it visually appears to be signed,  but it has no digital signature and hence, a viewer application does not report any  broken signature.In most cases, such a behavior is undesirable</para>  # noqa: E501

        :return: The flatten_signature_fields of this OptimizeAction.  # noqa: E501
        :rtype: bool
        """
        return self._flatten_signature_fields

    @flatten_signature_fields.setter
    def flatten_signature_fields(self, flatten_signature_fields):
        """Sets the flatten_signature_fields of this OptimizeAction.

        A signature in a PDF consist of two parts:  a.The invisible digital signature in the PDF.  b.The visual appearance that was attributed to the signature.  Part (a) can be used by a viewing application, to verify that a document has not changed since it has been signed  and report this to the user.Part(b) is merely a “decorative” element on the page without further significance.  When optimizing a PDF, the PDF is altered and hence the digital signature is broken.Therefore, all signatures are removed  , including parts(a) and(b).  When the property FlattenSignatureFields is set to True, then digital signatures(parts (a)) are still removed,  but their visual appearances(parts (b)) are flattened.I.e.the latter are retained and drawn as non-editable graphic  onto the page.  <para>  Note: The resulting PDF can be misleading as it visually appears to be signed,  but it has no digital signature and hence, a viewer application does not report any  broken signature.In most cases, such a behavior is undesirable</para>  # noqa: E501

        :param flatten_signature_fields: The flatten_signature_fields of this OptimizeAction.  # noqa: E501
        :type: bool
        """

        self._flatten_signature_fields = flatten_signature_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OptimizeAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptimizeAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.archive_config import ArchiveConfig  # noqa: F401,E501
from pdf4me.model.execution_trigger import ExecutionTrigger  # noqa: F401,E501
from pdf4me.model.storage_folder import StorageFolder  # noqa: F401,E501


class ArchiveJobReq(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'source_folder': 'StorageFolder',
        'execution_trigger': 'ExecutionTrigger',
        'archive_config': 'ArchiveConfig',
        'target_folder': 'StorageFolder'
    }

    attribute_map = {
        'job_id': 'jobId',
        'source_folder': 'sourceFolder',
        'execution_trigger': 'executionTrigger',
        'archive_config': 'archiveConfig',
        'target_folder': 'targetFolder'
    }

    def __init__(self, job_id=None, source_folder=None, execution_trigger=None, archive_config=None, target_folder=None):  # noqa: E501
        """ArchiveJobReq - a model defined in Swagger"""  # noqa: E501

        self._job_id = None
        self._source_folder = None
        self._execution_trigger = None
        self._archive_config = None
        self._target_folder = None
        self.discriminator = None

        self.job_id = job_id
        self.source_folder = source_folder
        self.execution_trigger = execution_trigger
        self.archive_config = archive_config
        self.target_folder = target_folder

    @property
    def job_id(self):
        """Gets the job_id of this ArchiveJobReq.  # noqa: E501


        :return: The job_id of this ArchiveJobReq.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this ArchiveJobReq.


        :param job_id: The job_id of this ArchiveJobReq.  # noqa: E501
        :type: str
        """
        if job_id is None:
            raise ValueError("Invalid value for `job_id`, must not be `None`")  # noqa: E501

        self._job_id = job_id

    @property
    def source_folder(self):
        """Gets the source_folder of this ArchiveJobReq.  # noqa: E501


        :return: The source_folder of this ArchiveJobReq.  # noqa: E501
        :rtype: StorageFolder
        """
        return self._source_folder

    @source_folder.setter
    def source_folder(self, source_folder):
        """Sets the source_folder of this ArchiveJobReq.


        :param source_folder: The source_folder of this ArchiveJobReq.  # noqa: E501
        :type: StorageFolder
        """
        if source_folder is None:
            raise ValueError("Invalid value for `source_folder`, must not be `None`")  # noqa: E501

        self._source_folder = source_folder

    @property
    def execution_trigger(self):
        """Gets the execution_trigger of this ArchiveJobReq.  # noqa: E501


        :return: The execution_trigger of this ArchiveJobReq.  # noqa: E501
        :rtype: ExecutionTrigger
        """
        return self._execution_trigger

    @execution_trigger.setter
    def execution_trigger(self, execution_trigger):
        """Sets the execution_trigger of this ArchiveJobReq.


        :param execution_trigger: The execution_trigger of this ArchiveJobReq.  # noqa: E501
        :type: ExecutionTrigger
        """
        if execution_trigger is None:
            raise ValueError("Invalid value for `execution_trigger`, must not be `None`")  # noqa: E501

        self._execution_trigger = execution_trigger

    @property
    def archive_config(self):
        """Gets the archive_config of this ArchiveJobReq.  # noqa: E501


        :return: The archive_config of this ArchiveJobReq.  # noqa: E501
        :rtype: ArchiveConfig
        """
        return self._archive_config

    @archive_config.setter
    def archive_config(self, archive_config):
        """Sets the archive_config of this ArchiveJobReq.


        :param archive_config: The archive_config of this ArchiveJobReq.  # noqa: E501
        :type: ArchiveConfig
        """
        if archive_config is None:
            raise ValueError("Invalid value for `archive_config`, must not be `None`")  # noqa: E501

        self._archive_config = archive_config

    @property
    def target_folder(self):
        """Gets the target_folder of this ArchiveJobReq.  # noqa: E501


        :return: The target_folder of this ArchiveJobReq.  # noqa: E501
        :rtype: StorageFolder
        """
        return self._target_folder

    @target_folder.setter
    def target_folder(self, target_folder):
        """Sets the target_folder of this ArchiveJobReq.


        :param target_folder: The target_folder of this ArchiveJobReq.  # noqa: E501
        :type: StorageFolder
        """
        if target_folder is None:
            raise ValueError("Invalid value for `target_folder`, must not be `None`")  # noqa: E501

        self._target_folder = target_folder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ArchiveJobReq, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArchiveJobReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.model import Extract, ExtractResources


class ExtractClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def extract(self, extract):
        """The predefined extraction is carried out.

        :param extract: extraction configuration
        :type extract: Extract
        :return: ExtractRes, contains extracted pages in form of a PDF
        """

        # check extract validity
        self.__check_extract_object_validity(extract)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=extract,
                                                                   controller='Extract/Extract')

        return res

    def extract_pages(self, page_nrs, file):
        """The chosen pages will be extracted from the given PDF and form a new PDF.

        :param page_nrs: the page numbers which will be extracted, number 1 corresponds to the first page.
        :type page_nrs: str: comma-separated page numbers (no spaces)
        :param file: to extract the pages from
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('pageNrs', page_nrs)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='Extract/ExtractPages')

    def extract_resources(self, extract_resources):
        """The predefined extraction is carried out.

        :param extract_resources: extraction configuration
        :type extract_resources: ExtractResources
        :return: ExtractResourcesRes, contains extracted resource info
        """

        # check extract_resources validity
        self.__check_extract_resources_object_validity(extract_resources)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=extract_resources,
                                                                   controller='Extract/ExtractResources')

        return res

    def __check_extract_object_validity(self, extract):
        """Checks whether the extract object contains the essential information to be
        processed by the server."""

        if extract is None:
            raise Pdf4meClientException('The extract parameter cannot be None.')
        elif extract.document is None or extract.document.doc_data is None:
            raise Pdf4meClientException('The extract document cannot be None.')
        elif extract.extract_action is None:
            raise Pdf4meClientException('The extract_action cannot be None.')
        elif extract.extract_action.extract_pages is None or len(extract.extract_action.extract_pages) == 0:
            raise Pdf4meClientException('The extract_pages of extract_action cannot be None or empty.')

    def __check_extract_resources_object_validity(self, extract_resources):
        """Checks whether the extract_resources object contains the essential information to be
        processed by the server."""

        if extract_resources is None:
            raise Pdf4meClientException('The extract_resources parameter cannot be None.')
        elif extract_resources.document is None or extract_resources.document.doc_data is None:
            raise Pdf4meClientException('The extract_resources document cannot be None.')
        elif extract_resources.extract_resources_action is None:
            raise Pdf4meClientException('The extract_resources_action cannot be None.')



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.doc_log import DocLog  # noqa: F401,E501
from pdf4me.model.doc_metadata import DocMetadata  # noqa: F401,E501
from pdf4me.model.page import Page  # noqa: F401,E501


class Document(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document_id': 'str',
        'name': 'str',
        'file_name': 'str',
        'file_extension': 'str',
        'doc_status': 'str',
        'pages': 'list[Page]',
        'doc_data': 'str',
        'doc_metadata': 'DocMetadata',
        'doc_logs': 'list[DocLog]',
        'document_url': 'str'
    }

    attribute_map = {
        'document_id': 'documentId',
        'name': 'name',
        'file_name': 'fileName',
        'file_extension': 'fileExtension',
        'doc_status': 'docStatus',
        'pages': 'pages',
        'doc_data': 'docData',
        'doc_metadata': 'docMetadata',
        'doc_logs': 'docLogs',
        'document_url': 'documentUrl'
    }

    def __init__(self, document_id=None, name=None, file_name=None, file_extension=None, doc_status=None, pages=None, doc_data=None, doc_metadata=None, doc_logs=None, document_url=None):  # noqa: E501
        """Document - a model defined in Swagger"""  # noqa: E501

        self._document_id = None
        self._name = None
        self._file_name = None
        self._file_extension = None
        self._doc_status = None
        self._pages = None
        self._doc_data = None
        self._doc_metadata = None
        self._doc_logs = None
        self._document_url = None
        self.discriminator = None

        if document_id is not None:
            self.document_id = document_id
        if name is not None:
            self.name = name
        if file_name is not None:
            self.file_name = file_name
        if file_extension is not None:
            self.file_extension = file_extension
        if doc_status is not None:
            self.doc_status = doc_status
        if pages is not None:
            self.pages = pages
        if doc_data is not None:
            self.doc_data = doc_data
        if doc_metadata is not None:
            self.doc_metadata = doc_metadata
        if doc_logs is not None:
            self.doc_logs = doc_logs
        if document_url is not None:
            self.document_url = document_url

    @property
    def document_id(self):
        """Gets the document_id of this Document.  # noqa: E501

        DocumentId  # noqa: E501

        :return: The document_id of this Document.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this Document.

        DocumentId  # noqa: E501

        :param document_id: The document_id of this Document.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def name(self):
        """Gets the name of this Document.  # noqa: E501

        Give filename inlcuding filetype  # noqa: E501

        :return: The name of this Document.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Document.

        Give filename inlcuding filetype  # noqa: E501

        :param name: The name of this Document.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def file_name(self):
        """Gets the file_name of this Document.  # noqa: E501


        :return: The file_name of this Document.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this Document.


        :param file_name: The file_name of this Document.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def file_extension(self):
        """Gets the file_extension of this Document.  # noqa: E501


        :return: The file_extension of this Document.  # noqa: E501
        :rtype: str
        """
        return self._file_extension

    @file_extension.setter
    def file_extension(self, file_extension):
        """Sets the file_extension of this Document.


        :param file_extension: The file_extension of this Document.  # noqa: E501
        :type: str
        """

        self._file_extension = file_extension

    @property
    def doc_status(self):
        """Gets the doc_status of this Document.  # noqa: E501

        Returns the Status of the Document  # noqa: E501

        :return: The doc_status of this Document.  # noqa: E501
        :rtype: str
        """
        return self._doc_status

    @doc_status.setter
    def doc_status(self, doc_status):
        """Sets the doc_status of this Document.

        Returns the Status of the Document  # noqa: E501

        :param doc_status: The doc_status of this Document.  # noqa: E501
        :type: str
        """

        self._doc_status = doc_status

    @property
    def pages(self):
        """Gets the pages of this Document.  # noqa: E501

        Description of pages  # noqa: E501

        :return: The pages of this Document.  # noqa: E501
        :rtype: list[Page]
        """
        return self._pages

    @pages.setter
    def pages(self, pages):
        """Sets the pages of this Document.

        Description of pages  # noqa: E501

        :param pages: The pages of this Document.  # noqa: E501
        :type: list[Page]
        """

        self._pages = pages

    @property
    def doc_data(self):
        """Gets the doc_data of this Document.  # noqa: E501


        :return: The doc_data of this Document.  # noqa: E501
        :rtype: str
        """
        return self._doc_data

    @doc_data.setter
    def doc_data(self, doc_data):
        """Sets the doc_data of this Document.


        :param doc_data: The doc_data of this Document.  # noqa: E501
        :type: str
        """
        if doc_data is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', doc_data):  # noqa: E501
            raise ValueError(r"Invalid value for `doc_data`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._doc_data = doc_data

    @property
    def doc_metadata(self):
        """Gets the doc_metadata of this Document.  # noqa: E501


        :return: The doc_metadata of this Document.  # noqa: E501
        :rtype: DocMetadata
        """
        return self._doc_metadata

    @doc_metadata.setter
    def doc_metadata(self, doc_metadata):
        """Sets the doc_metadata of this Document.


        :param doc_metadata: The doc_metadata of this Document.  # noqa: E501
        :type: DocMetadata
        """

        self._doc_metadata = doc_metadata

    @property
    def doc_logs(self):
        """Gets the doc_logs of this Document.  # noqa: E501


        :return: The doc_logs of this Document.  # noqa: E501
        :rtype: list[DocLog]
        """
        return self._doc_logs

    @doc_logs.setter
    def doc_logs(self, doc_logs):
        """Sets the doc_logs of this Document.


        :param doc_logs: The doc_logs of this Document.  # noqa: E501
        :type: list[DocLog]
        """

        self._doc_logs = doc_logs

    @property
    def document_url(self):
        """Gets the document_url of this Document.  # noqa: E501


        :return: The document_url of this Document.  # noqa: E501
        :rtype: str
        """
        return self._document_url

    @document_url.setter
    def document_url(self, document_url):
        """Sets the document_url of this Document.


        :param document_url: The document_url of this Document.  # noqa: E501
        :type: str
        """

        self._document_url = document_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Document, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Document):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Transform(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'a': 'int',
        'b': 'int',
        'c': 'int',
        'd': 'int',
        'x': 'int',
        'y': 'int'
    }

    attribute_map = {
        'a': 'a',
        'b': 'b',
        'c': 'c',
        'd': 'd',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, a=None, b=None, c=None, d=None, x=None, y=None):  # noqa: E501
        """Transform - a model defined in Swagger"""  # noqa: E501

        self._a = None
        self._b = None
        self._c = None
        self._d = None
        self._x = None
        self._y = None
        self.discriminator = None

        self.a = a
        self.b = b
        self.c = c
        self.d = d
        self.x = x
        self.y = y

    @property
    def a(self):
        """Gets the a of this Transform.  # noqa: E501


        :return: The a of this Transform.  # noqa: E501
        :rtype: int
        """
        return self._a

    @a.setter
    def a(self, a):
        """Sets the a of this Transform.


        :param a: The a of this Transform.  # noqa: E501
        :type: int
        """
        if a is None:
            raise ValueError("Invalid value for `a`, must not be `None`")  # noqa: E501

        self._a = a

    @property
    def b(self):
        """Gets the b of this Transform.  # noqa: E501


        :return: The b of this Transform.  # noqa: E501
        :rtype: int
        """
        return self._b

    @b.setter
    def b(self, b):
        """Sets the b of this Transform.


        :param b: The b of this Transform.  # noqa: E501
        :type: int
        """
        if b is None:
            raise ValueError("Invalid value for `b`, must not be `None`")  # noqa: E501

        self._b = b

    @property
    def c(self):
        """Gets the c of this Transform.  # noqa: E501


        :return: The c of this Transform.  # noqa: E501
        :rtype: int
        """
        return self._c

    @c.setter
    def c(self, c):
        """Sets the c of this Transform.


        :param c: The c of this Transform.  # noqa: E501
        :type: int
        """
        if c is None:
            raise ValueError("Invalid value for `c`, must not be `None`")  # noqa: E501

        self._c = c

    @property
    def d(self):
        """Gets the d of this Transform.  # noqa: E501


        :return: The d of this Transform.  # noqa: E501
        :rtype: int
        """
        return self._d

    @d.setter
    def d(self, d):
        """Sets the d of this Transform.


        :param d: The d of this Transform.  # noqa: E501
        :type: int
        """
        if d is None:
            raise ValueError("Invalid value for `d`, must not be `None`")  # noqa: E501

        self._d = d

    @property
    def x(self):
        """Gets the x of this Transform.  # noqa: E501


        :return: The x of this Transform.  # noqa: E501
        :rtype: int
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this Transform.


        :param x: The x of this Transform.  # noqa: E501
        :type: int
        """
        if x is None:
            raise ValueError("Invalid value for `x`, must not be `None`")  # noqa: E501

        self._x = x

    @property
    def y(self):
        """Gets the y of this Transform.  # noqa: E501


        :return: The y of this Transform.  # noqa: E501
        :rtype: int
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this Transform.


        :param y: The y of this Transform.  # noqa: E501
        :type: int
        """
        if y is None:
            raise ValueError("Invalid value for `y`, must not be `None`")  # noqa: E501

        self._y = y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Transform, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Transform):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

# from pdf4me.model.pdf_outline import PdfOutline  # noqa: F401,E501


class PdfOutline(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'childs': 'list[PdfOutline]',
        'count': 'int',
        'level': 'int',
        'title': 'str',
        'bottom': 'float',
        'left': 'float',
        'page_no': 'int',
        'right': 'float',
        'top': 'float',
        'type': 'str',
        'zoom': 'float'
    }

    attribute_map = {
        'childs': 'childs',
        'count': 'count',
        'level': 'level',
        'title': 'title',
        'bottom': 'bottom',
        'left': 'left',
        'page_no': 'pageNo',
        'right': 'right',
        'top': 'top',
        'type': 'type',
        'zoom': 'zoom'
    }

    def __init__(self, childs=None, count=None, level=None, title=None, bottom=None, left=None, page_no=None, right=None, top=None, type=None, zoom=None):  # noqa: E501
        """PdfOutline - a model defined in Swagger"""  # noqa: E501

        self._childs = None
        self._count = None
        self._level = None
        self._title = None
        self._bottom = None
        self._left = None
        self._page_no = None
        self._right = None
        self._top = None
        self._type = None
        self._zoom = None
        self.discriminator = None

        if childs is not None:
            self.childs = childs
        if count is not None:
            self.count = count
        if level is not None:
            self.level = level
        if title is not None:
            self.title = title
        if bottom is not None:
            self.bottom = bottom
        if left is not None:
            self.left = left
        if page_no is not None:
            self.page_no = page_no
        if right is not None:
            self.right = right
        if top is not None:
            self.top = top
        if type is not None:
            self.type = type
        if zoom is not None:
            self.zoom = zoom

    @property
    def childs(self):
        """Gets the childs of this PdfOutline.  # noqa: E501


        :return: The childs of this PdfOutline.  # noqa: E501
        :rtype: list[PdfOutline]
        """
        return self._childs

    @childs.setter
    def childs(self, childs):
        """Sets the childs of this PdfOutline.


        :param childs: The childs of this PdfOutline.  # noqa: E501
        :type: list[PdfOutline]
        """

        self._childs = childs

    @property
    def count(self):
        """Gets the count of this PdfOutline.  # noqa: E501


        :return: The count of this PdfOutline.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this PdfOutline.


        :param count: The count of this PdfOutline.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def level(self):
        """Gets the level of this PdfOutline.  # noqa: E501


        :return: The level of this PdfOutline.  # noqa: E501
        :rtype: int
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this PdfOutline.


        :param level: The level of this PdfOutline.  # noqa: E501
        :type: int
        """

        self._level = level

    @property
    def title(self):
        """Gets the title of this PdfOutline.  # noqa: E501


        :return: The title of this PdfOutline.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this PdfOutline.


        :param title: The title of this PdfOutline.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def bottom(self):
        """Gets the bottom of this PdfOutline.  # noqa: E501


        :return: The bottom of this PdfOutline.  # noqa: E501
        :rtype: float
        """
        return self._bottom

    @bottom.setter
    def bottom(self, bottom):
        """Sets the bottom of this PdfOutline.


        :param bottom: The bottom of this PdfOutline.  # noqa: E501
        :type: float
        """

        self._bottom = bottom

    @property
    def left(self):
        """Gets the left of this PdfOutline.  # noqa: E501


        :return: The left of this PdfOutline.  # noqa: E501
        :rtype: float
        """
        return self._left

    @left.setter
    def left(self, left):
        """Sets the left of this PdfOutline.


        :param left: The left of this PdfOutline.  # noqa: E501
        :type: float
        """

        self._left = left

    @property
    def page_no(self):
        """Gets the page_no of this PdfOutline.  # noqa: E501


        :return: The page_no of this PdfOutline.  # noqa: E501
        :rtype: int
        """
        return self._page_no

    @page_no.setter
    def page_no(self, page_no):
        """Sets the page_no of this PdfOutline.


        :param page_no: The page_no of this PdfOutline.  # noqa: E501
        :type: int
        """

        self._page_no = page_no

    @property
    def right(self):
        """Gets the right of this PdfOutline.  # noqa: E501


        :return: The right of this PdfOutline.  # noqa: E501
        :rtype: float
        """
        return self._right

    @right.setter
    def right(self, right):
        """Sets the right of this PdfOutline.


        :param right: The right of this PdfOutline.  # noqa: E501
        :type: float
        """

        self._right = right

    @property
    def top(self):
        """Gets the top of this PdfOutline.  # noqa: E501


        :return: The top of this PdfOutline.  # noqa: E501
        :rtype: float
        """
        return self._top

    @top.setter
    def top(self, top):
        """Sets the top of this PdfOutline.


        :param top: The top of this PdfOutline.  # noqa: E501
        :type: float
        """

        self._top = top

    @property
    def type(self):
        """Gets the type of this PdfOutline.  # noqa: E501


        :return: The type of this PdfOutline.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PdfOutline.


        :param type: The type of this PdfOutline.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def zoom(self):
        """Gets the zoom of this PdfOutline.  # noqa: E501


        :return: The zoom of this PdfOutline.  # noqa: E501
        :rtype: float
        """
        return self._zoom

    @zoom.setter
    def zoom(self, zoom):
        """Sets the zoom of this PdfOutline.


        :param zoom: The zoom of this PdfOutline.  # noqa: E501
        :type: float
        """

        self._zoom = zoom

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PdfOutline, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfOutline):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




from setuptools import setup, find_packages

with open('README.md') as f:
    long_description = f.read()


setup(
    name='pdf4me',
    version='0.8.13',
    description='Provides expert functionality to convert, optimize, merge, split, ocr, print documents & PDFs.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://portal.pdf4me.com/',
    author='Pdf4me',
    author_email='support-dev@pdf4me.com',
    classifiers=[
        'Development Status :: 4 - Beta',
        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development',
        'Topic :: Other/Nonlisted Topic',
        # license
        'License :: OSI Approved :: MIT License',
        # Supported python versions
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='pdf convert extract thumbnails merge optimize compress split stamp ocr archive',
    packages=find_packages(exclude=[]),
    # install_requires=['adal', 'inflection', 'requests', 'keyring', 'azure-mgmt-datalake-analytics', 'jprops'],
    install_requires=['inflection', 'requests', 'keyring', 'jprops'],
    python_requires='>=2.7, <4',
    project_urls={
        # 'Documentation': 'https://packaging.python.org/tutorials/distributing-packages/',
        'Bug Reports': 'https://github.com/pdf4me/pdf4me-clientapi-python/issues',
        'Source': 'https://github.com/pdf4me/pdf4me-clientapi-python',
    },
)



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.image import Image  # noqa: F401,E501
from pdf4me.model.text import Text  # noqa: F401,E501


class StampAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'page_sequence': 'str',
        'relative_pos_x': 'int',
        'relative_pos_y': 'int',
        'size_x': 'int',
        'size_y': 'int',
        'rotate': 'float',
        'autoorientation': 'bool',
        'alpha': 'float',
        'scale': 'str',
        'align_x': 'str',
        'align_y': 'str',
        'stamp_type': 'str',
        'text': 'Text',
        'image': 'Image'
    }

    attribute_map = {
        'page_sequence': 'pageSequence',
        'relative_pos_x': 'relativePosX',
        'relative_pos_y': 'relativePosY',
        'size_x': 'sizeX',
        'size_y': 'sizeY',
        'rotate': 'rotate',
        'autoorientation': 'autoorientation',
        'alpha': 'alpha',
        'scale': 'scale',
        'align_x': 'alignX',
        'align_y': 'alignY',
        'stamp_type': 'stampType',
        'text': 'text',
        'image': 'image'
    }

    def __init__(self, page_sequence=None, relative_pos_x=None, relative_pos_y=None, size_x=None, size_y=None, rotate=None, autoorientation=None, alpha=None, scale=None, align_x=None, align_y=None, stamp_type=None, text=None, image=None):  # noqa: E501
        """StampAction - a model defined in Swagger"""  # noqa: E501

        self._page_sequence = None
        self._relative_pos_x = None
        self._relative_pos_y = None
        self._size_x = None
        self._size_y = None
        self._rotate = None
        self._autoorientation = None
        self._alpha = None
        self._scale = None
        self._align_x = None
        self._align_y = None
        self._stamp_type = None
        self._text = None
        self._image = None
        self.discriminator = None

        if page_sequence is not None:
            self.page_sequence = page_sequence
        if relative_pos_x is not None:
            self.relative_pos_x = relative_pos_x
        if relative_pos_y is not None:
            self.relative_pos_y = relative_pos_y
        if size_x is not None:
            self.size_x = size_x
        if size_y is not None:
            self.size_y = size_y
        if rotate is not None:
            self.rotate = rotate
        if autoorientation is not None:
            self.autoorientation = autoorientation
        self.alpha = alpha
        if scale is not None:
            self.scale = scale
        if align_x is not None:
            self.align_x = align_x
        if align_y is not None:
            self.align_y = align_y
        if stamp_type is not None:
            self.stamp_type = stamp_type
        if text is not None:
            self.text = text
        if image is not None:
            self.image = image

    @property
    def page_sequence(self):
        """Gets the page_sequence of this StampAction.  # noqa: E501


        :return: The page_sequence of this StampAction.  # noqa: E501
        :rtype: str
        """
        return self._page_sequence

    @page_sequence.setter
    def page_sequence(self, page_sequence):
        """Sets the page_sequence of this StampAction.


        :param page_sequence: The page_sequence of this StampAction.  # noqa: E501
        :type: str
        """

        self._page_sequence = page_sequence

    @property
    def relative_pos_x(self):
        """Gets the relative_pos_x of this StampAction.  # noqa: E501


        :return: The relative_pos_x of this StampAction.  # noqa: E501
        :rtype: int
        """
        return self._relative_pos_x

    @relative_pos_x.setter
    def relative_pos_x(self, relative_pos_x):
        """Sets the relative_pos_x of this StampAction.


        :param relative_pos_x: The relative_pos_x of this StampAction.  # noqa: E501
        :type: int
        """

        self._relative_pos_x = relative_pos_x

    @property
    def relative_pos_y(self):
        """Gets the relative_pos_y of this StampAction.  # noqa: E501


        :return: The relative_pos_y of this StampAction.  # noqa: E501
        :rtype: int
        """
        return self._relative_pos_y

    @relative_pos_y.setter
    def relative_pos_y(self, relative_pos_y):
        """Sets the relative_pos_y of this StampAction.


        :param relative_pos_y: The relative_pos_y of this StampAction.  # noqa: E501
        :type: int
        """

        self._relative_pos_y = relative_pos_y

    @property
    def size_x(self):
        """Gets the size_x of this StampAction.  # noqa: E501


        :return: The size_x of this StampAction.  # noqa: E501
        :rtype: int
        """
        return self._size_x

    @size_x.setter
    def size_x(self, size_x):
        """Sets the size_x of this StampAction.


        :param size_x: The size_x of this StampAction.  # noqa: E501
        :type: int
        """

        self._size_x = size_x

    @property
    def size_y(self):
        """Gets the size_y of this StampAction.  # noqa: E501


        :return: The size_y of this StampAction.  # noqa: E501
        :rtype: int
        """
        return self._size_y

    @size_y.setter
    def size_y(self, size_y):
        """Sets the size_y of this StampAction.


        :param size_y: The size_y of this StampAction.  # noqa: E501
        :type: int
        """

        self._size_y = size_y

    @property
    def rotate(self):
        """Gets the rotate of this StampAction.  # noqa: E501


        :return: The rotate of this StampAction.  # noqa: E501
        :rtype: float
        """
        return self._rotate

    @rotate.setter
    def rotate(self, rotate):
        """Sets the rotate of this StampAction.


        :param rotate: The rotate of this StampAction.  # noqa: E501
        :type: float
        """

        self._rotate = rotate

    @property
    def autoorientation(self):
        """Gets the autoorientation of this StampAction.  # noqa: E501


        :return: The autoorientation of this StampAction.  # noqa: E501
        :rtype: bool
        """
        return self._autoorientation

    @autoorientation.setter
    def autoorientation(self, autoorientation):
        """Sets the autoorientation of this StampAction.


        :param autoorientation: The autoorientation of this StampAction.  # noqa: E501
        :type: bool
        """

        self._autoorientation = autoorientation

    @property
    def alpha(self):
        """Gets the alpha of this StampAction.  # noqa: E501

        The opacity of the stamp as a whole. 1.0 for fully opaque, 0.0 for fully transparent.  Default: 1.0  The PDF/A-1 standard does not allow transparency.Therefore, for PDF/A-1 conforming input files you must  not set alpha to a value other than 1.0  # noqa: E501

        :return: The alpha of this StampAction.  # noqa: E501
        :rtype: float
        """
        return self._alpha

    @alpha.setter
    def alpha(self, alpha):
        """Sets the alpha of this StampAction.

        The opacity of the stamp as a whole. 1.0 for fully opaque, 0.0 for fully transparent.  Default: 1.0  The PDF/A-1 standard does not allow transparency.Therefore, for PDF/A-1 conforming input files you must  not set alpha to a value other than 1.0  # noqa: E501

        :param alpha: The alpha of this StampAction.  # noqa: E501
        :type: float
        """
        # if alpha is None:
        #     raise ValueError("Invalid value for `alpha`, must not be `None`")  # noqa: E501

        self._alpha = alpha

    @property
    def scale(self):
        """Gets the scale of this StampAction.  # noqa: E501

        Modify scale of stamp. Allowed values for ‹scale_set› are:   - relToA4: Scale the stamp relative to the page size. For example, make stamp half as large on a A5 and  twice as large on a A3 page as specified.  # noqa: E501

        :return: The scale of this StampAction.  # noqa: E501
        :rtype: str
        """
        return self._scale

    @scale.setter
    def scale(self, scale):
        """Sets the scale of this StampAction.

        Modify scale of stamp. Allowed values for ‹scale_set› are:   - relToA4: Scale the stamp relative to the page size. For example, make stamp half as large on a A5 and  twice as large on a A3 page as specified.  # noqa: E501

        :param scale: The scale of this StampAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["relToA4"]  # noqa: E501
        if scale not in allowed_values:
            raise ValueError(
                "Invalid value for `scale` ({0}), must be one of {1}"  # noqa: E501
                .format(scale, allowed_values)
            )

        self._scale = scale

    @property
    def align_x(self):
        """Gets the align_x of this StampAction.  # noqa: E501


        :return: The align_x of this StampAction.  # noqa: E501
        :rtype: str
        """
        return self._align_x

    @align_x.setter
    def align_x(self, align_x):
        """Sets the align_x of this StampAction.


        :param align_x: The align_x of this StampAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["left", "center", "right"]  # noqa: E501
        if align_x not in allowed_values:
            raise ValueError(
                "Invalid value for `align_x` ({0}), must be one of {1}"  # noqa: E501
                .format(align_x, allowed_values)
            )

        self._align_x = align_x

    @property
    def align_y(self):
        """Gets the align_y of this StampAction.  # noqa: E501


        :return: The align_y of this StampAction.  # noqa: E501
        :rtype: str
        """
        return self._align_y

    @align_y.setter
    def align_y(self, align_y):
        """Sets the align_y of this StampAction.


        :param align_y: The align_y of this StampAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["top", "middle", "bottom"]  # noqa: E501
        if align_y not in allowed_values:
            raise ValueError(
                "Invalid value for `align_y` ({0}), must be one of {1}"  # noqa: E501
                .format(align_y, allowed_values)
            )

        self._align_y = align_y

    @property
    def stamp_type(self):
        """Gets the stamp_type of this StampAction.  # noqa: E501


        :return: The stamp_type of this StampAction.  # noqa: E501
        :rtype: str
        """
        return self._stamp_type

    @stamp_type.setter
    def stamp_type(self, stamp_type):
        """Sets the stamp_type of this StampAction.


        :param stamp_type: The stamp_type of this StampAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["annotation", "foreground", "background"]  # noqa: E501
        if stamp_type not in allowed_values:
            raise ValueError(
                "Invalid value for `stamp_type` ({0}), must be one of {1}"  # noqa: E501
                .format(stamp_type, allowed_values)
            )

        self._stamp_type = stamp_type

    @property
    def text(self):
        """Gets the text of this StampAction.  # noqa: E501


        :return: The text of this StampAction.  # noqa: E501
        :rtype: Text
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this StampAction.


        :param text: The text of this StampAction.  # noqa: E501
        :type: Text
        """

        self._text = text

    @property
    def image(self):
        """Gets the image of this StampAction.  # noqa: E501


        :return: The image of this StampAction.  # noqa: E501
        :rtype: Image
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this StampAction.


        :param image: The image of this StampAction.  # noqa: E501
        :type: Image
        """

        self._image = image

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StampAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StampAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from pdf4me.helper.json_converter import JsonConverter
from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.model import CreatePdfA, Rotate, Protect, Validate, Repair, SignPdf, DocMetadata


class PdfAClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def pdfA(self, create_pdfA):
        """The predefined PDF/A creation is carried out.

        :param create_pdfA: PDF/A configuration
        :type create_pdfA: CreatePdfA
        :return: CreatePdfARes, contains generated PDF/A.
        """

        # check create_pdfA validity
        self.__check_pdfA_object_validity(create_pdfA)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=create_pdfA,
                                                                   controller='PdfA/PdfA')

        return res

    def create_pdfA(self, file, pdf_compliance=None):
        """Converts PDF documents to the PDF/A format for long-term archiving.

        :param pdf_compliance: PDF/A compliance level
        :type pdf_compliance: str
        :param file: to be converted to PDF/A
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]

        if (pdf_compliance is None):
            params = []
        else:
            params = [('pdfCompliance', pdf_compliance)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='PdfA/CreatePdfA')

    def __check_pdfA_object_validity(self, create_pdfA):
        """checks whether the create_pdfA object contains the essential information to be
        processed by the server."""

        if create_pdfA is None:
            raise Pdf4meClientException('The create_pdfA parameter cannot be None.')
        elif create_pdfA.document is None or create_pdfA.document.doc_data is None:
            raise Pdf4meClientException('The create_pdfA document cannot be None.')
        elif create_pdfA.pdf_a_action is None:
            raise Pdf4meClientException('The pdf_a_action cannot be None.')

    # Rotate
    def rotate(self, rotate):
        """The predefined rotation is carried out.

        :param rotate: Rotate configuration
        :type rotate: Rotate
        :return: RotateRes, contains rotated pages.
        """

        # check rotate validity
        self.__check_rotate_object_validity(rotate)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=rotate,
                                                                   controller='PdfA/Rotate')

        return res

    def rotate_page(self, file, page_nr, rotate):
        """Rotates selected pages of the document in given direction.

        :param page_nr: determines after which page the rotate takes place
        :type page_nr: str
        :param rotate: determines rotate direction
        :type rotate: str
        :param file: file to be rotated
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('pageNr', page_nr), ('rotate', rotate)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='PdfA/RotatePage')

    def rotate_document(self, file, rotate):
        """Rotates all pages of the document in given direction.

        :param rotate: determines rotate direction
        :type rotate: str
        :param file: file to be rotated
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('rotate', rotate)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='PdfA/RotateDocument')

    def __check_rotate_object_validity(self, rotate):
        """checks whether the rotate object contains the essential information to be
        processed by the server."""

        if rotate is None:
            raise Pdf4meClientException('The rotate parameter cannot be None.')
        elif rotate.document is None or rotate.document.doc_data is None:
            raise Pdf4meClientException('The rotate document cannot be None.')
        elif rotate.rotate_action is None:
            raise Pdf4meClientException('The rotate_action cannot be None.')

    # Protect
    def protect(self, protect):
        """The predefined rotation is carried out.

        :param protect: protect configuration
        :type protect: Protect
        :return: ProtectRes, contains protected document.
        """

        # check protect validity
        self.__check_protect_object_validity(protect)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=protect,
                                                                   controller='PdfA/Protect')

        return res

    def protect_document(self, file, password, permissions):
        """protects selected pages of the document in given direction.

        :param password: password to be set for document
        :type password: str
        :param permissions: permissions to be set for document
        :type permissions: str
        :param file: to be protected
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('password', password), ('permissions', permissions)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='PdfA/ProtectDocument')

    def unlock_document(self, file, password):
        """protects all pages of the document in given direction.

        :param password: password of the document
        :type password: str
        :param file: to be unlocked
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('password', password)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='PdfA/UnlockDocument')

    def __check_protect_object_validity(self, protect):
        """checks whether the protect object contains the essential information to be
        processed by the server."""

        if protect is None:
            raise Pdf4meClientException('The protect parameter cannot be None.')
        elif protect.document is None or protect.document.doc_data is None:
            raise Pdf4meClientException('The protect document cannot be None.')
        elif protect.protect_action is None:
            raise Pdf4meClientException('The protect_action cannot be None.')

    # validate
    def validate(self, validate):
        """The predefined rotation is carried out.

        :param validate: validate configuration
        :type validate: Validate
        :return: validateRes, contains validation info.
        """

        # check validate validity
        self.__check_validate_object_validity(validate)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=validate,
                                                                   controller="PdfA/Validate")

        return res

    def validate_document(self, file, pdf_compliance):
        """validates selected pages of the document in given direction.

        :param pdf_compliance: PDF/A compliance to check
        :type pdf_compliance: str
        :param file: to be validated
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('pdfCompliance', pdf_compliance)]

        res = self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='PdfA/ValidateDocument')
        # get json
        res = JsonConverter().load(res)

        return res

    def __check_validate_object_validity(self, validate):
        """checks whether the validate object contains the essential information to be
        processed by the server."""

        if validate is None:
            raise Pdf4meClientException('The validate parameter cannot be None.')
        elif validate.document is None or validate.document.doc_data is None:
            raise Pdf4meClientException('The validate document cannot be None.')
        elif validate.validate_action is None:
            raise Pdf4meClientException('The validate_action cannot be None.')

    # Repair
    def repair(self, repair):
        """The predefined rotation is carried out.

        :param repair: repair configuration
        :type repair: Repair
        :return: repairRes, contains repaired document with validation info.
        """

        # check repair validity
        self.__check_repair_object_validity(repair)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=repair,
                                                                   controller="PdfA/Repair")

        return res

    def repair_document(self, file):
        """repairs selected pages of the document in given direction.

        :param file: to be repaired
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = []

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='PdfA/RepairDocument')

    def __check_repair_object_validity(self, repair):
        """checks whether the repair object contains the essential information to be
        processed by the server."""

        if repair is None:
            raise Pdf4meClientException('The repair parameter cannot be None.')
        elif repair.document is None or repair.document.doc_data is None:
            raise Pdf4meClientException('The repair document cannot be None.')
        # elif repair.repair_action is None:
        #    raise Pdf4meClientException('The repair_action cannot be None.')

    def sign_pdf(self, sign_pdf):
        """The predefined rotation is carried out.

        :param sign_pdf: SignPdf configuration
        :type sign_pdf: SignPdf
        :return: SignPdfRes, contains signed document.
        """

        # check sign_pdf validity
        self.__check_sign_pdf_object_validity(sign_pdf)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=sign_pdf,
                                                                   controller="PdfA/SignPdf")

        return res

    def __check_sign_pdf_object_validity(self, sign_pdf):
        """checks whether the sign_pdf object contains the essential information to be
        processed by the server."""

        if sign_pdf is None:
            raise Pdf4meClientException('The sign_pdf parameter cannot be None.')
        elif sign_pdf.document is None or sign_pdf.document.doc_data is None:
            raise Pdf4meClientException('The sign_pdf document cannot be None.')
        elif sign_pdf.sign_action is None:
            raise Pdf4meClientException('The sign_action cannot be None.')

    def metadata(self, file):
        """repairs selected pages of the document in given direction.

        :param file: to be repaired
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: DocMetadata, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = []

        res = self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                          controller='PdfA/Metadata')

        # get json
        return JsonConverter().load(res)




# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.rgb_set import RGBSet  # noqa: F401,E501


class CustomCMSConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'white': 'RGBSet',
        'c': 'RGBSet',
        'm': 'RGBSet',
        'y': 'RGBSet',
        'k': 'RGBSet',
        'cm': 'RGBSet',
        'cy': 'RGBSet',
        'ck': 'RGBSet',
        'my': 'RGBSet',
        'mk': 'RGBSet',
        'yk': 'RGBSet',
        'cmy': 'RGBSet',
        'cmk': 'RGBSet',
        'cyk': 'RGBSet',
        'myk': 'RGBSet',
        'cmyk': 'RGBSet'
    }

    attribute_map = {
        'white': 'white',
        'c': 'c',
        'm': 'm',
        'y': 'y',
        'k': 'k',
        'cm': 'cm',
        'cy': 'cy',
        'ck': 'ck',
        'my': 'my',
        'mk': 'mk',
        'yk': 'yk',
        'cmy': 'cmy',
        'cmk': 'cmk',
        'cyk': 'cyk',
        'myk': 'myk',
        'cmyk': 'cmyk'
    }

    def __init__(self, white=None, c=None, m=None, y=None, k=None, cm=None, cy=None, ck=None, my=None, mk=None, yk=None, cmy=None, cmk=None, cyk=None, myk=None, cmyk=None):  # noqa: E501
        """CustomCMSConfig - a model defined in Swagger"""  # noqa: E501

        self._white = None
        self._c = None
        self._m = None
        self._y = None
        self._k = None
        self._cm = None
        self._cy = None
        self._ck = None
        self._my = None
        self._mk = None
        self._yk = None
        self._cmy = None
        self._cmk = None
        self._cyk = None
        self._myk = None
        self._cmyk = None
        self.discriminator = None

        if white is not None:
            self.white = white
        if c is not None:
            self.c = c
        if m is not None:
            self.m = m
        if y is not None:
            self.y = y
        if k is not None:
            self.k = k
        if cm is not None:
            self.cm = cm
        if cy is not None:
            self.cy = cy
        if ck is not None:
            self.ck = ck
        if my is not None:
            self.my = my
        if mk is not None:
            self.mk = mk
        if yk is not None:
            self.yk = yk
        if cmy is not None:
            self.cmy = cmy
        if cmk is not None:
            self.cmk = cmk
        if cyk is not None:
            self.cyk = cyk
        if myk is not None:
            self.myk = myk
        if cmyk is not None:
            self.cmyk = cmyk

    @property
    def white(self):
        """Gets the white of this CustomCMSConfig.  # noqa: E501


        :return: The white of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._white

    @white.setter
    def white(self, white):
        """Sets the white of this CustomCMSConfig.


        :param white: The white of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._white = white

    @property
    def c(self):
        """Gets the c of this CustomCMSConfig.  # noqa: E501


        :return: The c of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._c

    @c.setter
    def c(self, c):
        """Sets the c of this CustomCMSConfig.


        :param c: The c of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._c = c

    @property
    def m(self):
        """Gets the m of this CustomCMSConfig.  # noqa: E501


        :return: The m of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._m

    @m.setter
    def m(self, m):
        """Sets the m of this CustomCMSConfig.


        :param m: The m of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._m = m

    @property
    def y(self):
        """Gets the y of this CustomCMSConfig.  # noqa: E501


        :return: The y of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this CustomCMSConfig.


        :param y: The y of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._y = y

    @property
    def k(self):
        """Gets the k of this CustomCMSConfig.  # noqa: E501


        :return: The k of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._k

    @k.setter
    def k(self, k):
        """Sets the k of this CustomCMSConfig.


        :param k: The k of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._k = k

    @property
    def cm(self):
        """Gets the cm of this CustomCMSConfig.  # noqa: E501


        :return: The cm of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._cm

    @cm.setter
    def cm(self, cm):
        """Sets the cm of this CustomCMSConfig.


        :param cm: The cm of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._cm = cm

    @property
    def cy(self):
        """Gets the cy of this CustomCMSConfig.  # noqa: E501


        :return: The cy of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._cy

    @cy.setter
    def cy(self, cy):
        """Sets the cy of this CustomCMSConfig.


        :param cy: The cy of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._cy = cy

    @property
    def ck(self):
        """Gets the ck of this CustomCMSConfig.  # noqa: E501


        :return: The ck of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._ck

    @ck.setter
    def ck(self, ck):
        """Sets the ck of this CustomCMSConfig.


        :param ck: The ck of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._ck = ck

    @property
    def my(self):
        """Gets the my of this CustomCMSConfig.  # noqa: E501


        :return: The my of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._my

    @my.setter
    def my(self, my):
        """Sets the my of this CustomCMSConfig.


        :param my: The my of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._my = my

    @property
    def mk(self):
        """Gets the mk of this CustomCMSConfig.  # noqa: E501


        :return: The mk of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._mk

    @mk.setter
    def mk(self, mk):
        """Sets the mk of this CustomCMSConfig.


        :param mk: The mk of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._mk = mk

    @property
    def yk(self):
        """Gets the yk of this CustomCMSConfig.  # noqa: E501


        :return: The yk of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._yk

    @yk.setter
    def yk(self, yk):
        """Sets the yk of this CustomCMSConfig.


        :param yk: The yk of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._yk = yk

    @property
    def cmy(self):
        """Gets the cmy of this CustomCMSConfig.  # noqa: E501


        :return: The cmy of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._cmy

    @cmy.setter
    def cmy(self, cmy):
        """Sets the cmy of this CustomCMSConfig.


        :param cmy: The cmy of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._cmy = cmy

    @property
    def cmk(self):
        """Gets the cmk of this CustomCMSConfig.  # noqa: E501


        :return: The cmk of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._cmk

    @cmk.setter
    def cmk(self, cmk):
        """Sets the cmk of this CustomCMSConfig.


        :param cmk: The cmk of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._cmk = cmk

    @property
    def cyk(self):
        """Gets the cyk of this CustomCMSConfig.  # noqa: E501


        :return: The cyk of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._cyk

    @cyk.setter
    def cyk(self, cyk):
        """Sets the cyk of this CustomCMSConfig.


        :param cyk: The cyk of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._cyk = cyk

    @property
    def myk(self):
        """Gets the myk of this CustomCMSConfig.  # noqa: E501


        :return: The myk of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._myk

    @myk.setter
    def myk(self, myk):
        """Sets the myk of this CustomCMSConfig.


        :param myk: The myk of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._myk = myk

    @property
    def cmyk(self):
        """Gets the cmyk of this CustomCMSConfig.  # noqa: E501


        :return: The cmyk of this CustomCMSConfig.  # noqa: E501
        :rtype: RGBSet
        """
        return self._cmyk

    @cmyk.setter
    def cmyk(self, cmyk):
        """Sets the cmyk of this CustomCMSConfig.


        :param cmyk: The cmyk of this CustomCMSConfig.  # noqa: E501
        :type: RGBSet
        """

        self._cmyk = cmyk

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomCMSConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomCMSConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
